$bases = {
           'name' => 'body_0',
           'base_string' => {
                              'stock alert' => 'STOCK_ALERT,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __STOCK_TIP,[l=1]',
                              'gift' => '__RECEIVE_BONUS,[l=1]',
                              'foreign offshore account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_TCC,[l=0] __HK_SCAM_N15,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'kopieer en plak het' => '__COPY_PASTE_NL,[l=0]',
                              'retrieve yourheld ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' tuesday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'venture' => '__DEAL,[l=1]',
                              'defunt' => '__DECEASED,[l=1]',
                              '\\366verskridit gr\\344nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'on holiday' => '__BOUNCE_OOO_CB2,[l=1] __DAY_I_EARNED,[l=1]',
                              'to continue using your online' => 'FREE_QUOTE_INSTANT,[l=1] __ACCESS_RESTORE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'be welcomed with' => '__RECEIVE_BONUS,[l=1]',
                              'buy for ' => '__PUMPDUMP_07,[l=1] __YOU_WON_02,[l=1]',
                              'recommend this company' => '__DEAL,[l=1] __PUMPDUMP_06,[l=1] __THIS_AD,[l=1]',
                              'remuneration' => '__FRAUD_WNY,[l=1]',
                              'cons=e9quence' => '__YOU_WON_04,[l=1]',
                              '=f6verskridit gr\\344nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'million u' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __FRAUD_LTX,[l=1]',
                              '=f6verskridit gr\\344nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'times an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'you receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'click_here' => '__OBFU_UNSUB_UL,[l=1]',
                              'earliest response' => '__FRAUD_DPR,[l=1] __URG_BIZ,[l=1]',
                              'recommended a company' => '__PUMPDUMP_06,[l=1]',
                              'medications online' => 'FREE_QUOTE_INSTANT,[l=1] ONLINE_PHARMACY,[l=1]',
                              'you\'re received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'not a registered investment advisor' => 'NOT_ADVISOR,[l=0] __INVEST_MONEY,[l=1] __SUBSCRIPTION_INFO,[l=1] __SUM_OF_FUND,[l=1]',
                              'quemar' => '__DESTROY_ME,[l=1]',
                              'size of ' => 'BODY_ENHANCEMENT2,[l=1] TVD_INCREASE_SIZE,[l=1]',
                              'you\'re receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'tripling an principle' => '__PUMPDUMP_01,[l=1]',
                              'metallic' => '__TRUNK_BOX,[l=1]',
                              'tue' => '__DOS_BODY_TUE,[l=1]',
                              'trading at such a bargain' => '__PUMPDUMP_10,[l=1]',
                              'secret pin' => '__HUSH_HUSH,[l=1] __KAM_LOTTO2,[l=1]',
                              'i was let go from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'mail address w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1] __hk_win_b,[l=1]',
                              'disabled' => '__ACH_CANCELLED_03,[l=1]',
                              'security center' => '__FEES,[l=1] __SYSADMIN,[l=1] __TRUNK_BOX,[l=1]',
                              'you have receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dear candidate' => 'DEAR_SOMETHING,[l=1]',
                              'earn' => '__RECEIVE_BONUS,[l=1]',
                              'quadrupling an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'm 25' => '__DOS_I_AM_25,[l=1]',
                              'mandamus' => '__WILL_LEGAL,[l=1]',
                              'immediate reply' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1]',
                              'your mailer do not support html messages' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RUDE_HTML_4,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '=f6verskridit gr\\344nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'illegal attachment' => '__DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'we have sent ' => '__WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'without' => '__WITHOUT_EFFORT,[l=1]',
                              'act of 193' => 'TVD_ACT_193,[l=1]',
                              'make your e' => '__ACCOUNT_SECURE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'mon' => '__DOS_BODY_MON,[l=1]',
                              'our_mail' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'without exercising' => 'DIET_1,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'collaborate' => '__FRAUD_XWW,[l=1]',
                              'we are not spam' => 'NOT_SPAM,[l=1]',
                              'recommend a stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1]',
                              'lotto international' => '__FRAUD_RLX,[l=1] __HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'support center' => '__SYSADMIN,[l=1]',
                              'priv\\351' => '__HUSH_HUSH,[l=1]',
                              'investment' => '__INVEST_MONEY,[l=1] __SUM_OF_FUND,[l=1]',
                              'nations' => '__UN,[l=1]',
                              'automatically reduce your ' => '__CLEAN_MAILBOX,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'death' => '__NOT_DEAD_YET,[l=1]',
                              'tripling your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cialis' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1]',
                              'zusammenarbeit' => '__FRAUD_XWW,[l=1]',
                              'honestly' => '__FRAUD_XWW,[l=1]',
                              'no exercising' => 'DIET_1,[l=1]',
                              'adultdatingcompany' => '__ADULTDATINGCOMPANY_BODY,[l=1]',
                              'i was let go from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'legitimate business' => '__DEAL,[l=1] __FRAUD_UUY,[l=1] __GAPPY_SALES_LEADS,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'you\'ve received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'quadrupling your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'without dieting' => 'DIET_1,[l=1] __DEAL,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'desk' => '__SYSADMIN,[l=1]',
                              ' digit level in ' => '__DOS_TAKING_HOME,[l=1]',
                              'accepted' => '__ACH_CANCELLED_03,[l=1]',
                              'scam' => '__NOT_SCAM,[l=1] __SCAM,[l=1]',
                              'not bother you again' => '__DEAL,[l=1] __NEVER_HEAR_EN,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'transform your life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'b\\303\\251nin' => '__BENIN,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'i am currently out of the office' => '__BOUNCE_OOO_B2,[l=1] __BOUNCE_OOO_CB1,[l=1] __DEAL,[l=1]',
                              '\\366verskridit gr\\344nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              '\\366verskridit gr=e4nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'quadruple an principal' => '__PUMPDUMP_01,[l=1]',
                              'excess return capital fund' => 'EMRCP,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              ' opens tuesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'travel itinerary' => '__TRAVEL_AGENT,[l=1] __TRAVEL_ITINERARY,[l=0]',
                              'percent' => '__AGREED_RATIO,[l=1] __FRAUD_JYG,[l=1]',
                              'next' => '__NEXT_OF_KIN,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              '=e5terst=e4lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              'this offer is only for usa' => '__DEAL,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              '=f6verskridit gr\\344nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'leave you alone' => '__NEVER_HEAR_EN,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'claim this money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1] __LOTTO_DEPT,[l=1] __THIS_AD,[l=1]',
                              ' first thing tomorrow' => '__PUMPDUMP_03,[l=1]',
                              'l c' => '__DRUGS_ERECTILE5,[l=1]',
                              'eliminare tutti i tuoi segreti' => '__NEVER_HEAR_IT,[l=0]',
                              'euro-pw' => '__HK_LOTTO_2,[l=1]',
                              'to zugreifen wiederhergestellt' => '__ACCESS_RESTORE,[l=1]',
                              'quadrupling your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lose' => 'DIET_1,[l=1]',
                              'be given' => '__FRAUD_JYG,[l=1] __RECEIVE_BONUS,[l=1]',
                              'unrepairable virus detected' => 'BAD_CREDIT,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'you have receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'section 27a' => 'TVD_SECTION,[l=1]',
                              'securities storage house' => '__FRAUD_IRJ,[l=0] __STOCK_TIP,[l=1]',
                              'sun' => '__DOS_BODY_SUN,[l=1]',
                              'holding firm' => '__FRAUD_IRJ,[l=0]',
                              'securities firm' => '__FRAUD_IRJ,[l=0]',
                              'financially independen' => 'FIN_FREE,[l=1] __DEAL,[l=1]',
                              'going out of your house' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'sements' => '__ADMITS_SPAM,[l=1] __THIS_AD,[l=1]',
                              'drop me a line at' => '__DOS_DROP_ME_A_LINE,[l=1]',
                              'ausgleich' => '__COMPENSATION,[l=1]',
                              'your account is' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_ERROR,[l=1] __ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you\'ve receiving this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'asassination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'account oversea' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_N15,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'times an principle' => '__PUMPDUMP_01,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'ti garantisco che non ti disturbe' => '__NEVER_HEAR_IT,[l=0]',
                              'triple your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'i was dismissed from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'to any foreigner' => '__FRAUD_XJR,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'you are receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'unit' => '__LOTTO_DEPT,[l=1]',
                              'my name is engr' => '__FRAUD_QXX,[l=1]',
                              'alternative ' => '__FRAUD_AON,[l=1]',
                              'eliminate' => 'BAD_CREDIT,[l=1]',
                              'each' => '__PILL_PRICE_01,[l=1]',
                              'mail sweepstake' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_BALLOT,[l=1] __YOU_WON_01,[l=1]',
                              ' tomorrow first thing' => '__PUMPDUMP_03,[l=1]',
                              'oprah!' => 'BANG_OPRAH,[l=1]',
                              'lotto' => '__HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'priv=e9' => '__HUSH_HUSH,[l=1]',
                              'you do' => '__RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' media relations' => 'DX_TEXT_03,[l=1]',
                              'section 21b' => 'TVD_SECTION,[l=1]',
                              'you\'ve receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'excess maximum return capital profit' => 'EMRCP,[l=1] __YOUR_PROFIT,[l=1]',
                              'secret arrangement' => '__HK_SCAM_N16,[l=1] __HUSH_HUSH,[l=1]',
                              ' to our members' => '__WE_PAID,[l=1]',
                              'password upgrade' => '__PASSWORD_UPGRADE,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'you\'ve receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' dollars bonus offer' => '__BONUS_LAST_DAY,[l=1] __RECEIVE_BONUS,[l=1]',
                              'forwarded message' => '__ADMAIL,[l=1] __YOU_WON_02,[l=1] __freemail_safe_fwd,[l=1]',
                              'to remove this suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1] __SUBSCRIPTION_INFO,[l=1] __THIS_AD,[l=1]',
                              'dear madam' => 'DEAR_SOMETHING,[l=1]',
                              'newsletter' => '__SUBSCRIPTION_INFO,[l=1]',
                              'left' => '__DORMANT_ACCT,[l=1]',
                              'download yourpending ' => '__DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'urgent' => '__URG_BIZ,[l=1]',
                              'veuve' => '__WIDOW,[l=1]',
                              'executor' => '__WILL_LEGAL,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'die' => '__DEAL,[l=1]',
                              'compensate' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1]',
                              ' opens friday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              '\\366verskridit gr=e4nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              '\\366verskridit gr=e4nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'steady and increasing course' => '__DOS_STEADY_COURSE,[l=1]',
                              'activation of your ' => '__ACCESS_REVOKE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'times your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'aboration' => '__FRAUD_XWW,[l=1]',
                              'risk' => '__FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1]',
                              'tablet' => '__PILL_PRICE_01,[l=1]',
                              'incurable' => '__AM_DYING,[l=1] __FRAUD_WNY,[l=1]',
                              'leaving your home' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lucky number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1] __LUCKY_WINNER,[l=1]',
                              'vous etes' => '__YOU_WON_04,[l=1]',
                              'disburs' => '__FRAUD_FBI,[l=1] __FRAUD_WNY,[l=1]',
                              'klonopin' => '__DRUGS_ANXIETY8,[l=1]',
                              'funds transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __SUM_OF_FUND,[l=1] __WIRE_XFR,[l=1] __YOUR_FUND,[l=1] __hk_win_i,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'loteri' => '__HK_LOTTO_2,[l=1]',
                              'charit' => '__CHARITY,[l=1]',
                              'an honest foreigner' => '__FRAUD_XJR,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'foundation' => '__FOUND_YOU,[l=1] __HK_LOTTO_2,[l=1]',
                              'award' => '__LOTTO_DEPT,[l=1]',
                              'triple an principle' => '__PUMPDUMP_01,[l=1]',
                              'verification' => '__LOTTO_VERIFY,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'out of the office' => '__BOUNCE_OOO_CB1,[l=1] __DEAL,[l=1]',
                              'will' => '__I_WILL_YOU,[l=1] __RECEIVE_BONUS,[l=1]',
                              'seleccion al azar' => '__RANDOM_PICK,[l=1]',
                              'i am barrister' => '__BARRISTER,[l=1] __CONTACT_ATTY,[l=1] __FRAUD_QXX,[l=1]',
                              'my name is prince' => '__FRAUD_QXX,[l=1]',
                              'clamation de votre prix' => '__YOU_ASSIST,[l=1] __hk_win_m,[l=1]',
                              'ihre kreditkarte weist einige sicherheitsprobleme' => '__ACCOUNT_SECURE,[l=1] __YOUR_FUND,[l=1]',
                              '<num_not_date_ip>' => '__LOTSA_MONEY_05,[l=1]',
                              'virus scanner deleted your message' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __VBOUNCE_CLICKBANK,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you\'ve received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'geheim' => '__HUSH_HUSH,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'overseas account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_N15,[l=1]',
                              'heritage' => '__MY_FORTUNE,[l=1]',
                              'bank of ghana' => '__GHANA,[l=1] __HK_SCAM_S25,[l=1]',
                              'mail are not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'vous \\352tes' => '__YOU_WON_04,[l=1]',
                              'upgrade center' => '__SYSADMIN,[l=1]',
                              'bonus' => '__RECEIVE_BONUS,[l=1]',
                              '\\366verskridit gr\\344nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              ' to our partners' => '__WE_PAID,[l=1]',
                              'you\'re receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'que ha ganado' => '__HAS_WON_01,[l=1]',
                              'details' => '__LOTTO_WIN_01,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'invest' => '__INVEST_MONEY,[l=1]',
                              'urgent response' => '__FRAUD_DPR,[l=1] __URG_BIZ,[l=1]',
                              'secure fund' => '__FRAUD_WFC,[l=1] __SUM_OF_FUND,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1]',
                              'consignment' => '__TRUNK_BOX,[l=1] __YOUR_CONSIGNMENT,[l=1]',
                              'weiter zur aktualisierung' => '__ACCOUNT_UPGRADE,[l=1]',
                              'escogidos aleatoria' => '__RANDOM_PICK,[l=1]',
                              'hole in the banking' => 'LOOPHOLE_1,[l=1] __DEAL,[l=1]',
                              'mail clean' => '__ADMAIL,[l=1] __CLEAN_MAILBOX,[l=1] __DRUGS_ERECTILE5,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'd\\303\\251funt' => '__DECEASED,[l=1]',
                              'this message are not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __THIS_AD,[l=1]',
                              'microsoft' => '__LOTTO_ADMITS_2,[l=1]',
                              'this offer for usa' => '__DEAL,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'loterie' => '__HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'winning numbers' => '__LOTTO_WIN_01,[l=1] __hk_win_a,[l=1]',
                              ' tuesday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'in has been accessed' => '__MAIL_ACCT_ACCESS1,[l=1]',
                              'bad' => 'BAD_CREDIT,[l=1]',
                              'make you thousands' => '__FRAUD_LTX,[l=1] __PUMPDUMP_04,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'honest cooperation' => '__FRAUD_XVW,[l=1] __FRAUD_XWW,[l=1]',
                              'reason: rejected by filter' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __VBOUNCE_REJ_FILT,[l=1]',
                              'update' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'release your ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'snap up as many shares as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'our_email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'v i r u s' => '__VBOUNCE_AMAVISD2,[l=1]',
                              'diplomatic' => '__DIPLOMATIC,[l=1]',
                              'you\'re receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mail draw' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1] __YOU_WON_01,[l=1]',
                              'lucky' => '__LUCKY_WINNER,[l=1]',
                              'suporte t\\351cnico' => '__SYSADMIN,[l=1]',
                              'soma' => 'DRUGS_SMEAR1,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'your account ' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_ERROR,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' please view this message in a different' => '__ADMAIL,[l=1] __DEAL,[l=1] __RUDE_HTML_2,[l=1] __THIS_AD,[l=1]',
                              'vous \\303\\252tes' => '__YOU_WON_04,[l=1]',
                              'este correo no puede ser considerado spam' => 'NOT_SPAM,[l=1]',
                              'burn' => 'DIET_1,[l=1]',
                              'collect your prize' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_n,[l=1]',
                              'money back guarantee' => 'MONEY_BACK,[l=0] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1]',
                              'to uplift the suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1]',
                              'respond immediately' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1]',
                              'treatment' => '__TRTMT_DEFILED,[l=1]',
                              'security' => '__FEES,[l=1] __TRUNK_BOX,[l=1]',
                              'establish' => 'BAD_CREDIT,[l=1]',
                              ' less 10%' => '__FOR_SALE_LTP,[l=1]',
                              ' friday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              'arrangement secret' => '__HK_SCAM_N16,[l=1] __HUSH_HUSH,[l=1]',
                              'committee' => '__LOTTO_DEPT,[l=1]',
                              'processing' => '__FEES,[l=1] __LOTTO_DEPT,[l=1]',
                              'rejected' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1]',
                              'bureau' => '__LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'finance storage house' => '__FRAUD_IRJ,[l=0] __STOCK_TIP,[l=1]',
                              'download them now' => '__DEAL,[l=1] __DLND_ATTACH,[l=1] __RELEASE_MESSAGES,[l=1]',
                              'stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __STOCK_TIP,[l=1]',
                              'asassinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'affidavit' => '__FRAUD_ULK,[l=1]',
                              'individual' => '__LUCKY_WINNER,[l=1]',
                              'compliment of the' => '__DEAL,[l=1] __FRAUD_IRT,[l=1]',
                              'ihr' => '__YOUR_FUND,[l=1]',
                              'information' => '__LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'quadruple an principle' => '__PUMPDUMP_01,[l=1]',
                              'dept' => '__LOTTO_DEPT,[l=1]',
                              ' thursday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              '\\345terst=e4lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'line ballot' => '__HK_LOTTO_BALLOT,[l=1]',
                              'group securiq' => '__LOTTO_DEPT,[l=1] __VBOUNCE_SECURIQ,[l=1]',
                              'foreign customer' => '__FRAUD_MQO,[l=0] __LOTTO_DEPT,[l=1] __STOCK_TIP,[l=1] __YOU_WON_02,[l=1]',
                              'expiration date' => '__PDS_EXPIRATION_NOTICE,[l=1]',
                              'whanger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              ' first thing thursday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'you\'re receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'address direclty at' => '__DOS_EMAIL_DIRECTLY,[l=1]',
                              'contact details' => '__CONTACT_ATTY,[l=1] __FRAUD_ETX,[l=1] __FRAUD_JYG,[l=1] __LOTTO_WIN_01,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'selection' => '__RANDOM_PICK,[l=1]',
                              'going out of residence' => '__STAY_HOME,[l=1]',
                              'mittel' => '__SUM_OF_FUND,[l=1]',
                              'impotence cure' => 'IMPOTENCE,[l=1]',
                              'free xxx' => 'FREE_PORN,[l=1] __PILL_PRICE_01,[l=1]',
                              'security team' => '__FEES,[l=1] __SYSADMIN,[l=1] __TRUNK_BOX,[l=1]',
                              'refinance your home' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'barr.' => '__BARRISTER,[l=1]',
                              'discovered a dormant account' => '__DORMANT_ACCT,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_S15,[l=0]',
                              'please do not resend your original message.' => '__ADMAIL,[l=1] __BOUNCE_NO_RESEND,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __freemail_safe_fwd,[l=1]',
                              '=f6verskridit gr=e4nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'fiduciary' => '__HK_LOTTO_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'a honest foreigner' => '__FRAUD_XJR,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              ' i\'ll never see your message' => '__ADMAIL,[l=1] __BOUNCE_NEVER_SEE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __NOT_SCAM,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'has stripped one or more attachments from the following mess' => '__DEAL,[l=1] __DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_STRIP_ATTACH,[l=1]',
                              'excess return capital profit' => 'EMRCP,[l=1] __YOUR_PROFIT,[l=1]',
                              ' extended relative' => '__FRAUD_SNT,[l=1]',
                              'admin center' => '__SYSADMIN,[l=1]',
                              ' gates' => '__HK_LOTTO_2,[l=1]',
                              'contact' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1]',
                              'cancer' => '__AM_DYING,[l=1]',
                              'https://docs.google.com/forms/' => '__UNSUB_GOOG_FORM,[l=1] __YOU_WON_02,[l=1]',
                              'invoice' => '__FRAUD_QFY,[l=1]',
                              'cash prize of' => '__CASHPRZ,[l=1] __LOTTO_WIN_01,[l=1]',
                              'shore account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1]',
                              'inches' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] DIET_1,[l=1]',
                              'sildenafil' => 'DRUG_ED_SILD,[l=1]',
                              '\\345terst\\344lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              'serial number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'draw' => '__LOTTO_WIN_01,[l=1]',
                              'the attachment was quarantined' => '__DEAL,[l=1] __DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_ATT_QUAR,[l=1]',
                              '=f6verskridit gr\\344nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'ficiary' => 'DEAR_BENEFICIARY,[l=1]',
                              'nigerian government' => '__FRAUD_QFY,[l=1] __FRAUD_YQV,[l=0] __NIGERIA,[l=1]',
                              'quintuple your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' wednesday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'retrieve your ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'be we can meet' => '__DOS_MEET_EACH_OTHER,[l=1]',
                              'you have reached a non' => '__BOUNCE_NONWORKING,[l=1] __PILL_PRICE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'foreign business partner' => '__DEAL,[l=1] __FRAUD_MQO,[l=0] __FRAUD_TDP,[l=1] __GAPPY_SALES_LEADS,[l=1] __LOTTO_DEPT,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1] __YOU_WON_02,[l=1]',
                              'taking home ' => '__DOS_TAKING_HOME,[l=1]',
                              'fund' => '__SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'make you hundreds' => '__PUMPDUMP_04,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'impotence problem' => 'IMPOTENCE,[l=1]',
                              'help' => '__SYSADMIN,[l=1]',
                              'triple your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'remunerration' => '__FRAUD_WNY,[l=1]',
                              'last day of the bonus offer' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1]',
                              'dear investor' => 'DEAR_SOMETHING,[l=1] __INVEST_MONEY,[l=1] __STOCK_TIP,[l=1]',
                              '\\366verskridit gr\\344nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'lottery co' => '__AFF_LOTTERY,[l=0] __FRAUD_RLX,[l=1] __HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'investment advice' => 'INVESTMENT_ADVICE,[l=1] __INVEST_MONEY,[l=1] __SUM_OF_FUND,[l=1]',
                              'rolex' => 'EM_ROLEX,[l=1]',
                              'time investment' => 'ONE_TIME,[l=1] __INVEST_MONEY,[l=1] __SUM_OF_FUND,[l=1]',
                              'dying' => '__AM_DYING,[l=1]',
                              'you\'ve receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'clarification and procedure' => '__hk_win_o,[l=1]',
                              'computer' => '__RANDOM_PICK,[l=1]',
                              'you are received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'the late president' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_EZY,[l=1]',
                              'holding company' => '__FRAUD_IRJ,[l=0]',
                              'price' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1]',
                              'seas bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1]',
                              'to restore access' => '__ACCESS_RESTORE,[l=1] __STOCK_TIP,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'no thanks' => 'REMOVE_BEFORE_LINK,[l=1]',
                              'died' => '__DEAL,[l=1] __DIED_IN,[l=1]',
                              'this message is not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __THIS_AD,[l=1]',
                              'upgrade team' => '__SYSADMIN,[l=1]',
                              'inherit' => '__NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1] __YOU_INHERIT,[l=1]',
                              'you\'re receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'le copier et le coller' => '__COPY_PASTE_FR,[l=0]',
                              '=f6verskridit gr=e4nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'cristal' => '__HK_LOTTO_2,[l=1]',
                              'you are receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'suspend ' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'expiration notice' => '__PDS_EXPIRATION_NOTICE,[l=1]',
                              'nigerian national' => '__FRAUD_YQV,[l=0] __HK_LOTTO_2,[l=1] __NIGERIA,[l=1]',
                              'kopiera den och klistra in' => '__COPY_PASTE_SE,[l=0]',
                              'assasination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'valium' => 'DRUGS_SMEAR1,[l=1] __DRUGS_ANXIETY_VAL,[l=0]',
                              '\\303\\266verskridit gr\\344nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'phendimetrazine' => '__DRUGS_DIET4,[l=1]',
                              'you have receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lost' => 'DIET_1,[l=1]',
                              'you receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'furnish you with' => '__FRAUD_YWW,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'reference number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'mercato' => '__HK_LOTTO_2,[l=1]',
                              'ticket number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'destroy all your secrets' => '__DECEASED,[l=1] __DESTROY_ME,[l=1] __DESTROY_YOU,[l=1] __GAPPY_SALES_LEADS,[l=1] __HUSH_HUSH,[l=1] __NEVER_HEAR_EN,[l=0] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'without exercise' => 'DIET_1,[l=1] __WITHOUT_EFFORT,[l=1]',
                              ' extra effort' => 'DIET_1,[l=1] __RECEIVE_BONUS,[l=1] __WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              'i won' => '__YOU_WON_05,[l=1]',
                              'front' => '__FEES,[l=1]',
                              'istance' => '__YOU_ASSIST,[l=1]',
                              '=f6verskridit gr=e4nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'earned' => '__DAY_I_EARNED,[l=1] __RECEIVE_BONUS,[l=1]',
                              'penis' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'you receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'grab as many shares of it as i can' => '__PUMPDUMP_09,[l=1]',
                              'transaction' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_MCQ,[l=1]',
                              'enlarge' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'partner site' => 'MARKETING_PARTNERS,[l=1]',
                              'found' => '__FOUND_YOU,[l=1]',
                              'network partner' => 'MARKETING_PARTNERS,[l=1]',
                              'your access is' => '__ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'winner' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __hk_win_2,[l=1]',
                              'your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'auto accident' => '__AUTO_ACCIDENT,[l=0] __DECEASED,[l=1]',
                              'computer draw' => '__HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1] __RANDOM_PICK,[l=1]',
                              'd\\303\\251nt' => '__DECEASED,[l=1]',
                              '\\366verskridit gr\\344nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'you are received this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dear web' => 'DEAR_SOMETHING,[l=1]',
                              'esgic plus' => '__DRUGS_PAIN12,[l=1]',
                              'you are receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'current itinerary' => '__TRAVEL_ITINERARY,[l=0]',
                              'join millions' => 'JOIN_MILLIONS,[l=1] MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __MILLIONS,[l=1]',
                              'foreign offshore bank' => '__FRAUD_TCC,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'travel' => '__TRAVEL_AGENT,[l=1]',
                              'une mallette m=e9tallique' => '__TRUNK_BOX,[l=1]',
                              '=f6verskridit gr\\344nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'une mallette m\\351tallique' => '__TRUNK_BOX,[l=1]',
                              'be awarded' => '__LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1]',
                              '\\303\\245terst=e4lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              ' ticket agent' => '__LOTTO_AGENT_02,[l=1]',
                              's greetings' => '__FRAUD_IRT,[l=1]',
                              'sement_' => '__ADMITS_SPAM,[l=1] __THIS_AD,[l=1]',
                              'ihre kreditkarte wird gesperrt' => '__ACCESS_REVOKE,[l=1] __YOUR_FUND,[l=1]',
                              'you\'ve receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' friday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              'leaving house' => '__STAY_HOME,[l=1]',
                              'capsules' => '__PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'i am prince' => '__FRAUD_QXX,[l=1]',
                              'you\'ve been ' => '__RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'compensation' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1] __LOTTO_DEPT,[l=1]',
                              'phentermine' => '__DRUGS_DIET_PHEN,[l=1]',
                              'univers' => '__HK_LOTTO_2,[l=1]',
                              'guarantee the safety of your ' => '__DEAL,[l=1] __DECEASED,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_07,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' thursday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'avoid double claiming' => '__DBLCLAIM,[l=1] __LOTTO_DEPT,[l=1]',
                              'this offer is for usa' => '__DEAL,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'dick' => 'BODY_ENHANCEMENT2,[l=1]',
                              'mutual' => '__DEAL,[l=1]',
                              '\\366verskridit gr=e4nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'i am dr' => '__FRAUD_QXX,[l=1]',
                              'caplet' => '__PILL_PRICE_01,[l=1]',
                              'to continue using your mailbox' => '__ACCESS_RESTORE,[l=1] __ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'vital documents' => '__FRAUD_UOQ,[l=0]',
                              ' to our clients' => '__WE_PAID,[l=1]',
                              'profit' => '__YOUR_PROFIT,[l=1]',
                              'box clean' => '__CLEAN_MAILBOX,[l=1]',
                              'leaving your house' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'n restricted status' => '__TVD_PH_BODY_01,[l=1]',
                              'diethylpropion' => '__DEAL,[l=1] __DRUGS_DIET5,[l=1]',
                              ' first thing friday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              'costs' => '__FB_COST,[l=1] __FRAUD_QFY,[l=1]',
                              'selected' => '__RANDOM_PICK,[l=1]',
                              'istant' => '__YOU_ASSIST,[l=1]',
                              ' to our subscribers' => '__SUBSCRIPTION_INFO,[l=1] __WE_PAID,[l=1]',
                              'i was layed off from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'hunt' => '__DESTROY_ME,[l=1]',
                              'united' => '__LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'download yourunreceived ' => '__DAY_I_EARNED,[l=1] __DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'financial free' => 'FIN_FREE,[l=1] __DEAL,[l=1] __PILL_PRICE_01,[l=1]',
                              ' million' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1]',
                              'modality' => '__FRAUD_THJ,[l=0]',
                              'to your ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'last day of the $' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1]',
                              'costing' => '__FB_COST,[l=1] __FRAUD_QFY,[l=1]',
                              'e direclty at' => '__DOS_EMAIL_DIRECTLY,[l=1]',
                              'contacting' => '__CONTACT_ATTY,[l=1] __CONTACT_YOU,[l=1] __FRAUD_JYG,[l=1]',
                              'for your organi' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TO_YOUR_ORG,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'your winning' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_5,[l=1]',
                              'prescr' => 'NO_PRESCRIPTION,[l=1]',
                              'ricaine' => '__HK_LOTTO_2,[l=1]',
                              'dear friend' => '__DOS_BODY_FRI,[l=1] __FRAUD_IRT,[l=1]',
                              'afortunados' => '__LUCKY_WINNER,[l=1] __YOU_WON_02,[l=1]',
                              'country' => '__INVEST_COUNTRY,[l=1]',
                              'kopieren sie es und f\\374gen sie es ein' => '__COPY_PASTE_DE,[l=0]',
                              'refinance your current home' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'quadruple your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'quintupling an principle' => '__PUMPDUMP_01,[l=1]',
                              'projected' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1]',
                              'upgrade of your access' => '__ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'declining' => '__ACH_CANCELLED_02,[l=1]',
                              'discreet' => '__HUSH_HUSH,[l=1]',
                              'destroy' => '__DESTROY_ME,[l=1] __DESTROY_YOU,[l=1]',
                              'permanent removal of your ' => '__ACCESS_REVOKE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'shot' => 'CUM_SHOT,[l=1]',
                              'illion dollar' => 'BILLION_DOLLARS,[l=1]',
                              'you\'re receive this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'direct telephone number' => '__HK_SCAM_N3,[l=1] __LOTTO_WIN_01,[l=1]',
                              'securing monies' => '__DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1]',
                              'line draw' => '__HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1]',
                              'recommends a company' => '__PUMPDUMP_06,[l=1]',
                              'inheri' => '__YOU_INHERIT,[l=1]',
                              'tery' => '__LOTTO_DEPT,[l=1]',
                              'password is due for expiration yesterday' => '__DAY_I_EARNED,[l=1] __PASSWORD_EXP_CLUMSY,[l=1] __YOU_WON_02,[l=1]',
                              'nigeria' => '__NIGERIA,[l=1]',
                              'transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __WIRE_XFR,[l=1]',
                              'replica' => 'REPLICA_WATCH,[l=1]',
                              'please reduce the ' => '__CLEAN_MAILBOX,[l=1] __DEAL,[l=1]',
                              'cilias' => '__DRUGS_ERECTILE4,[l=1]',
                              'over-invoice' => '__FRAUD_QFY,[l=1] __FRAUD_YJA,[l=0]',
                              'mail ballot' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_BALLOT,[l=1] __YOU_WON_01,[l=1]',
                              'the' => '__DEAL,[l=1]',
                              'suspicion login' => '__SUSPICION_LOGIN,[l=1]',
                              'trading at a low' => '__PUMPDUMP_10,[l=1]',
                              'tour' => '__FB_TOUR,[l=1]',
                              'bigger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              '=f6verskridit gr=e4nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              ' wednesday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'geld' => '__YOUR_FUND,[l=1]',
                              'you\'re received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'kopieren sie es und f\\303\\274gen sie es ein' => '__COPY_PASTE_DE,[l=0]',
                              'attourney' => '__CONTACT_ATTY,[l=1] __FB_TOUR,[l=1]',
                              'thu' => '__DOS_BODY_THU,[l=1]',
                              'pleasure to inform' => '__YOU_WON_02,[l=1] __hk_win_4,[l=1]',
                              'message' => '__ADMAIL,[l=1]',
                              'quintupling an principal' => '__PUMPDUMP_01,[l=1]',
                              'received' => '__DAY_I_EARNED,[l=1]',
                              'secure the fund' => '__DEAL,[l=1] __FRAUD_WFC,[l=1] __SUM_OF_FUND,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1]',
                              'you\'ve receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'online' => 'FREE_QUOTE_INSTANT,[l=1]',
                              'salutaire' => '__LUCRATIVE,[l=1]',
                              'be handed' => '__RECEIVE_BONUS,[l=1]',
                              ' net' => '__FOR_SALE_NET,[l=1]',
                              'asasinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'quintuple an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'mail cannot be considered spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DRUGS_ERECTILE5,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'telegraph' => '__WIRE_XFR,[l=1]',
                              'quadrupling your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' opens tomorrow' => '__PUMPDUMP_03,[l=1]',
                              'nigeria government' => '__FRAUD_QFY,[l=1] __FRAUD_YQV,[l=0] __NIGERIA,[l=1]',
                              'quintuple your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cashier' => '__TRUSTED_CHECK,[l=1]',
                              'killers' => '__FRAUD_PTX,[l=1]',
                              '\\366verskridit gr=e4nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              '100% guaranteed' => 'GUARANTEED_100_PERCENT,[l=0]',
                              'my name is mr' => '__FRAUD_QXX,[l=1]',
                              'attached to ticket number' => '__FRAUD_BGP,[l=1] __KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1] __PLS_REVIEW,[l=1]',
                              'les tueurs' => '__DOS_BODY_TUE,[l=1] __FRAUD_PTX,[l=1]',
                              'vagira' => '__DRUGS_ERECTILE2,[l=1]',
                              'you have receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mailsweeper has found that a ' => '__ADMAIL,[l=1] __FOUND_YOU,[l=1] __GAPPY_SALES_LEADS,[l=1] __VBOUNCE_MAILSWEEP,[l=1] __YOU_WON_01,[l=1]',
                              'our_list' => '__OBFU_UNSUB_UL,[l=1]',
                              'alkuper\\344inen viesti' => '__freemail_safe_fwd,[l=1]',
                              'random' => '__RANDOM_PICK,[l=1]',
                              'suporte t=e9cnico' => '__SYSADMIN,[l=1]',
                              ' first thing tuesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'dormant' => '__DORMANT_ACCT,[l=1]',
                              '=f6verskridit gr\\344nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              ' before thursday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'on vacation' => '__BOUNCE_OOO_CB2,[l=1]',
                              'to be removed' => 'EXCUSE_4,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'trading at a bargain' => '__PUMPDUMP_10,[l=1]',
                              'mail is not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'second chance' => '__FRAUD_GBW,[l=1]',
                              'national' => '__HK_LOTTO_2,[l=1]',
                              'terminally' => '__AM_DYING,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'trust bank' => '__FRAUD_BEP,[l=1]',
                              'you' => '__RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'quintuple your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'quality medications' => 'TVD_QUAL_MEDS,[l=1]',
                              'impotence solution' => 'IMPOTENCE,[l=1]',
                              'we have remitted ' => '__FRAUD_WNY,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'ivoire' => '__IVORY_COAST,[l=1]',
                              'support team' => '__SYSADMIN,[l=1]',
                              'zebutal' => '__DRUGS_PAIN11,[l=1]',
                              'assasinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              ' credit' => 'BAD_CREDIT,[l=1]',
                              'financial independen' => 'FIN_FREE,[l=1] __DEAL,[l=1]',
                              'get a capable html e-mailer' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __RUDE_HTML_1,[l=0] __YOU_WON_01,[l=1]',
                              'poison' => '__FRAUD_PTX,[l=1]',
                              'ivory' => '__IVORY_COAST,[l=1]',
                              'grab it for ' => '__PUMPDUMP_07,[l=1] __YOU_WON_02,[l=1]',
                              'testament' => '__WILL_LEGAL,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'quintupling an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              '\\366verskridit gr=e4nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'losing your ' => 'DIET_1,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PDS_SEO2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'security firm' => '__FEES,[l=1] __FRAUD_IRJ,[l=0] __TRUNK_BOX,[l=1]',
                              'canadian dolla' => 'NA_DOLLARS,[l=1]',
                              'be started with' => '__RECEIVE_BONUS,[l=1]',
                              'fioricet' => '__DRUGS_PAIN_FIO,[l=0]',
                              'ful log' => '__FAILED_LOGINS,[l=1]',
                              'administration center' => '__SYSADMIN,[l=1]',
                              '\\303\\245terst\\303\\244lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              'fucking' => 'LIVE_PORN,[l=1]',
                              'keeping' => '__FEES,[l=1]',
                              'r\\363zne komputery zalogowaniu sie' => '__LOTTO_DEPT,[l=1] __MAIL_ACCT_ACCESS1,[l=1]',
                              'expiration alert' => '__PDS_EXPIRATION_NOTICE,[l=1]',
                              'you received this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amount' => '__SUM_OF_FUND,[l=1]',
                              'i was fired from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'sto' => '__STOCK_TIP,[l=1]',
                              '% after' => '__LARGE_PERCENT_AFTER,[l=1]',
                              'your e' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'assistance' => '__URG_BIZ,[l=1] __YOU_ASSIST,[l=1]',
                              'times your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pleased to inform' => '__YOU_WON_02,[l=1] __hk_win_4,[l=1]',
                              'guaranteed!' => 'BANG_GUAR,[l=1]',
                              'xjs*c4jdbqadn1.nsbn3*2idnen*gtube-standard-anti-ube-test-ema' => 'GTUBE,[l=1]',
                              'make you big bucks' => '__PUMPDUMP_04,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'alternate ' => '__FRAUD_AON,[l=1]',
                              'seas account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1]',
                              'bontril' => '__DRUGS_DIET3,[l=1]',
                              'recommends this stock' => '__DEAL,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1] __THIS_AD,[l=1]',
                              'through' => '__FRAUD_MLY,[l=1]',
                              'remunerate' => '__FRAUD_WNY,[l=1]',
                              'sweepstakes' => '__LOTTO_ADMITS_2,[l=1]',
                              'thicker' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'fri' => '__DOS_BODY_FRI,[l=1]',
                              'wife of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1]',
                              'terminale' => '__AM_DYING,[l=1]',
                              'have' => '__YOU_WON_01,[l=1]',
                              'claim' => '__LOTTO_DEPT,[l=1]',
                              'grab as many shares as i can' => '__PUMPDUMP_09,[l=1]',
                              'fund transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __SUM_OF_FUND,[l=1] __WIRE_XFR,[l=1] __YOUR_FUND,[l=1] __hk_win_i,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'partnership' => '__DEAL,[l=1]',
                              'daughter of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1]',
                              'benefit' => '__BACK_SCRATCH,[l=1]',
                              'escolhidos al azar' => '__RANDOM_PICK,[l=1]',
                              'homeless' => '__CHARITY,[l=1]',
                              'capsule' => '__PILL_PRICE_01,[l=1]',
                              'you\'ve receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'multiply your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you\'re received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' price' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1]',
                              'buy as many shares as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'recommended a stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1]',
                              'staatsloteri' => '__HK_LOTTO_2,[l=1] __HK_LOTTO_STAATS,[l=1]',
                              'copiarlo y pegarlo' => '__COPY_PASTE_ES,[l=0]',
                              'recompense' => '__COMPENSATION,[l=1]',
                              'internet ballot' => '__HK_LOTTO_BALLOT,[l=1]',
                              'mail sur internet' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1] __hk_win_c,[l=1]',
                              'computer ballot system' => '__FRAUD_CKF,[l=0] __HK_LOTTO_BALLOT,[l=1] __RANDOM_PICK,[l=1]',
                              'restore' => '__STOCK_TIP,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'dear car shopper' => 'DEAR_SOMETHING,[l=1]',
                              'sat' => '__DOS_BODY_SAT,[l=1]',
                              ' opens monday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'untimely' => '__EARLY_DEMISE,[l=1]',
                              'refinanc' => 'REFINANCE_NOW,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'you\'ve received this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cost' => '__FB_COST,[l=1]',
                              'next of kin' => '__HK_SCAM_N2,[l=1] __NEXT_OF_KIN,[l=1]',
                              'line sweepstake' => '__HK_LOTTO_BALLOT,[l=1]',
                              'r=f3zne komputery zalogowaniu sie' => '__LOTTO_DEPT,[l=1] __MAIL_ACCT_ACCESS1,[l=1]',
                              'leaving residence' => '__STAY_HOME,[l=1]',
                              'time charge' => 'ONE_TIME,[l=1] __FEES,[l=1]',
                              'widowe' => '__WIDOW,[l=1]',
                              'survey' => '__SURVEY,[l=1]',
                              'make an extra dollar' => 'DIET_1,[l=1] __MAKE_XTRA_DOLLAR,[l=1] __RECEIVE_BONUS,[l=1]',
                              'increase' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] MORE_SEX,[l=1]',
                              'fiducia' => '__LOTTO_DEPT,[l=1]',
                              'multiply an principle' => '__PUMPDUMP_01,[l=1]',
                              ' first thing wednesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'you have receiving this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'remove_your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __OBFU_UNSUB_UL,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fortune' => '__I_WILL_YOU,[l=1] __MY_FORTUNE,[l=1] __YOU_WON_02,[l=1]',
                              'winning pay' => '__FEES,[l=1] __PAY_YOU,[l=1] __hk_win_j,[l=1]',
                              'you have receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' ltp' => '__FOR_SALE_LTP,[l=1]',
                              'act now' => 'ACT_NOW_CAPS,[l=1]',
                              'group' => '__LOTTO_DEPT,[l=1]',
                              'congratulation to your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_7,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'private lawyer' => '__FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __FRAUD_WDR,[l=1] __HUSH_HUSH,[l=1]',
                              'you receive this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'asasination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'day' => '__DAY_I_EARNED,[l=1]',
                              '\\366verskridit gr=e4nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'schlong' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'target' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1]',
                              'securing the monies' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1]',
                              'free adult' => 'FREE_PORN,[l=1] __PILL_PRICE_01,[l=1]',
                              'computer sweepstake' => '__HK_LOTTO_BALLOT,[l=1] __RANDOM_PICK,[l=1]',
                              'future_email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'secure the monies' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'd=e9nt' => '__DECEASED,[l=1]',
                              'via' => 'VIA_GAP_GRA,[l=1]',
                              'meet each other' => '__DEAL,[l=1] __DOS_MEET_EACH_OTHER,[l=1] __PILL_PRICE_01,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'ganador' => '__LUCKY_WINNER,[l=1]',
                              'remunerrate' => '__FRAUD_WNY,[l=1]',
                              'you\'ve receive this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cette' => '__DEAL,[l=1]',
                              'vioxx' => '__DRUGS_PAIN_VIOXX,[l=0]',
                              'we have issued ' => '__WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'antivirus system report' => '__VBOUNCE_AVREPORT0,[l=0]',
                              ' monday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'sensitive' => '__HUSH_HUSH,[l=1]',
                              'sea bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1]',
                              'i drive a' => '__DOS_I_DRIVE_A,[l=1]',
                              'over' => '__FRAUD_QFY,[l=1]',
                              'get as many shares of it as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you\'re receiving this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'vous =c3=aates' => '__YOU_WON_04,[l=1]',
                              'you have receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you have receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'change your life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'change your daily life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'unclaimed' => 'UNCLAIMED_MONEY,[l=1] __LOTTO_DEPT,[l=1]',
                              'correspond with me using my email' => '__ADMAIL,[l=1] __DOS_CORRESPOND_EMAIL,[l=1] __FRAUD_MLY,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'accounts' => '__DORMANT_ACCT,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'recommended this company' => '__DEAL,[l=1] __PUMPDUMP_06,[l=1] __THIS_AD,[l=1]',
                              'viaegra' => 'VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE2,[l=1]',
                              'in your country' => '__DECEASED,[l=1] __FRAUD_IPK,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'to continue using your account' => '__ACCESS_RESTORE,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'confiden' => '__HUSH_HUSH,[l=1]',
                              'make for your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'remmit' => '__FRAUD_WNY,[l=1]',
                              'united state dollar' => 'MILLION_USD,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              '\\303\\245terst\\344lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              'the antivirus module has' => '__DEAL,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'grow' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'dent' => '__DECEASED,[l=1]',
                              'mail account been accessed' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ADMAIL,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __MAIL_ACCT_ACCESS1,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __WEBMAIL_ACCT,[l=1] __YOU_WON_01,[l=1]',
                              'e me at' => '__DOS_WRITE_ME_AT,[l=1]',
                              'obscure' => '__HUSH_HUSH,[l=1]',
                              'excess maximum return capital fund' => 'EMRCP,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              ' bank member' => '__TVD_PH_BODY_06,[l=1]',
                              'cons\\351quence' => '__YOU_WON_04,[l=1]',
                              'you have been ' => '__RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'account ' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'quintuple an principal' => '__PUMPDUMP_01,[l=1]',
                              'release yourunreceived ' => '__DAY_I_EARNED,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '=f6verskridit gr=e4nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              ' before wednesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'deposit' => '__ACH_CANCELLED_02,[l=1] __DORMANT_ACCT,[l=1]',
                              'transa' => '__DEAL,[l=1]',
                              'le copier + coller' => '__COPY_PASTE_FR,[l=0]',
                              'confidential ' => '__DECEASED,[l=1] __FRAUD_AON,[l=1] __FRAUD_MCQ,[l=1] __HUSH_HUSH,[l=1] __URG_BIZ,[l=1]',
                              'return to the office' => '__BOUNCE_OOO_CB4,[l=1] __DEAL,[l=1]',
                              'recommend this stock' => '__DEAL,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1] __THIS_AD,[l=1]',
                              'the desk of' => '__DEAL,[l=1] __FRAUD_AUM,[l=1] __SYSADMIN,[l=1]',
                              'verstorbenen' => '__DECEASED,[l=1] __STOCK_TIP,[l=1]',
                              'prize' => '__LOTTO_WIN_01,[l=1]',
                              'b\\351nin' => '__BENIN,[l=1]',
                              'quintupling your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'longer' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'reply immediately' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1]',
                              ' first thing monday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'respond urgently' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __URG_BIZ,[l=1]',
                              'financial advantage' => '__DEAL,[l=1] __DOS_FIN_ADVANTAGE,[l=1]',
                              'i was layed off from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'department' => '__HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'final day of the $' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1]',
                              'wanger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'going out of home' => '__STAY_HOME,[l=1]',
                              ' tomorrow morning' => '__PUMPDUMP_03,[l=1]',
                              'release yourheld ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'temporary removal of your ' => '__ACCESS_REVOKE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'free porn' => 'FREE_PORN,[l=1] __PILL_PRICE_01,[l=1]',
                              'draft' => '__BANK_DRAFT,[l=1]',
                              'tablets' => '__PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'une mallette metallique' => '__TRUNK_BOX,[l=1]',
                              'can you be my partner' => '__HK_SCAM_S15,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' great effort' => '__WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              'money' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1]',
                              'vertraulich' => '__HUSH_HUSH,[l=1]',
                              'bank of nigeria' => '__FRAUD_BEP,[l=1] __FRAUD_NEB,[l=0] __NIGERIA,[l=1]',
                              'you are receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' before tuesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'suporte t\\303\\251cnico' => '__SYSADMIN,[l=1]',
                              'freigabe' => '__SUM_OF_FUND,[l=1]',
                              'my name is barrister' => '__BARRISTER,[l=1] __CONTACT_ATTY,[l=1] __FRAUD_QXX,[l=1]',
                              'university mail server copyright' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_2,[l=1] __SYSADMIN,[l=1] __YOU_WON_01,[l=1]',
                              'recommends this company' => '__DEAL,[l=1] __PUMPDUMP_06,[l=1] __THIS_AD,[l=1]',
                              'you being a foreigner' => '__FRAUD_XJR,[l=0] __LOTTO_DEPT,[l=1] __NOT_DEAD_YET,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'l$>5bz9-9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'promo' => '__THIS_AD,[l=1]',
                              'we cannot be considered spam' => 'NOT_SPAM,[l=1]',
                              'affordable ' => 'PRICES_ARE_AFFORDABLE,[l=1] __YOU_WON_02,[l=1]',
                              'give' => '__FRAUD_JYG,[l=1]',
                              'prestige' => '__HK_LOTTO_2,[l=1]',
                              'dear it' => 'DEAR_SOMETHING,[l=1]',
                              'marketing' => '__GAPPY_SALES_LEADS,[l=1]',
                              'million' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1]',
                              'killing' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'you\'re receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'd=e9funt' => '__DECEASED,[l=1]',
                              'quote' => 'FREE_QUOTE_INSTANT,[l=1]',
                              'concerning this money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1] __THIS_AD,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'being' => '__NOT_DEAD_YET,[l=1]',
                              'you have received this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '\\345terst\\303\\244lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              'sichere ' => '__FRAUD_XWW,[l=1]',
                              'multiply an principal' => '__PUMPDUMP_01,[l=1]',
                              'message contains file attachments that are not permitted' => '__ADMAIL,[l=1] __DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_GUIN,[l=1]',
                              'administrator' => '__SYSADMIN,[l=1]',
                              'leaving your residence' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you are received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'male enhancement' => 'MALE_ENHANCE,[l=0]',
                              'b=e9nin' => '__BENIN,[l=1]',
                              'quality meds' => 'TVD_QUAL_MEDS,[l=1]',
                              ' to your e' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __MAIL_ACCT_ACCESS2,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'violation: quota size' => 'BODY_ENHANCEMENT2,[l=1] __CLEAN_MAILBOX,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'strong buy' => 'STRONG_BUY,[l=0]',
                              'security storage house' => '__FEES,[l=1] __FRAUD_IRJ,[l=0] __STOCK_TIP,[l=1] __TRUNK_BOX,[l=1]',
                              'tripling your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'was deleted' => '__VBOUNCE_ATTACHMENT0,[l=1]',
                              'assassinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'poor' => 'BAD_CREDIT,[l=1]',
                              'management center' => '__SYSADMIN,[l=1]',
                              'we have already issued ' => '__WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'as the beneficiary' => 'DEAR_BENEFICIARY,[l=1] __DEAL,[l=1] __FRAUD_PVN,[l=0]',
                              'you are subscription' => '__RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'concerning the money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1]',
                              'trading at such a low' => '__PUMPDUMP_10,[l=1]',
                              'cheque' => '__LOTTO_WIN_01,[l=1]',
                              'claim the money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1] __LOTTO_DEPT,[l=1]',
                              'you are receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'no dieting' => 'DIET_1,[l=1] __DEAL,[l=1]',
                              'we have already sent ' => '__WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'offshore account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __HK_SCAM_N15,[l=1]',
                              'you\'ve received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'united states dollar' => 'MILLION_USD,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'promotional ballot' => '__HK_LOTTO_BALLOT,[l=1] __THIS_AD,[l=1]',
                              'be remitted' => '__FRAUD_WNY,[l=1] __RECEIVE_BONUS,[l=1]',
                              'mail' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'xan' => '__DRUGS_ANXIETY_XAN,[l=1]',
                              '.pk' => '__DOS_BODY_TICKER,[l=1]',
                              ' monday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'the total sum' => '__DEAL,[l=1] __FRAUD_JYG,[l=1] __FRAUD_YPO,[l=0]',
                              'trading at a cheap' => '__PUMPDUMP_10,[l=1]',
                              'free' => '__PILL_PRICE_01,[l=1]',
                              'viagra' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE_V,[l=1]',
                              'safe' => '__FEES,[l=1]',
                              'you receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'e directly at' => '__DOS_EMAIL_DIRECTLY,[l=1]',
                              'wed' => '__DOS_BODY_WED,[l=1]',
                              'inheritance' => '__INHERIT_PMT,[l=1] __NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1] __YOU_INHERIT,[l=1]',
                              'sharing' => '__AGREED_RATIO,[l=1]',
                              'reimbursement' => '__ADMITS_SPAM,[l=1] __LOTTO_DEPT,[l=1]',
                              'african' => '__AFR_UNION,[l=1] __DOS_BODY_FRI,[l=1]',
                              'you\'re receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'i am engr' => '__FRAUD_QXX,[l=1]',
                              'retrieve yourunreceived ' => '__DAY_I_EARNED,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'i was dismissed from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'gestionnaire' => '__CONTACT_ATTY,[l=1]',
                              'act of nineteen thirty' => 'TVD_ACT_193,[l=1]',
                              'contacte' => '__CONTACT_ATTY,[l=1] __CONTACT_YOU,[l=1] __FRAUD_JYG,[l=1]',
                              'quintuple an principle' => '__PUMPDUMP_01,[l=1]',
                              'you are received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'olen lomalla' => '__BOUNCE_OOO_CB3,[l=1]',
                              'bank in ghana' => '__GHANA,[l=1] __HK_SCAM_S25,[l=1]',
                              'intended' => '__ADMITS_SPAM,[l=1]',
                              'unsubscribe here' => 'REMOVE_BEFORE_LINK,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              ' tuesday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'grab as many shares of it as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'express' => 'FREE_QUOTE_INSTANT,[l=1]',
                              'mail has w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1] __hk_win_b,[l=1]',
                              'secure' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'trunk' => '__TRUNK_BOX,[l=1]',
                              'brother of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1]',
                              ' thursday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'virgin' => 'LIVE_PORN,[l=1]',
                              'attached' => '__PLS_REVIEW,[l=1]',
                              'you have receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'consequence' => '__YOU_WON_04,[l=1]',
                              'this offer for united states' => '__DEAL,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              'personal email at' => '__ADMAIL,[l=1] __DOS_PERSONAL_EMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'viaggra' => 'VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE2,[l=1]',
                              ' opens wednesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'i was fired from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __YOU_WON_02,[l=1]',
                              'assassination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'ghana' => '__GHANA,[l=1]',
                              'foreign bank' => '__FRAUD_TCC,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'dear traveler' => 'DEAR_SOMETHING,[l=1] __TRAVEL_AGENT,[l=1]',
                              'with no effort' => '__WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              'millions' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __MILLIONS,[l=1]',
                              'activat' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'online ph' => 'FREE_QUOTE_INSTANT,[l=1] TVD_VISIT_PHARMA,[l=1]',
                              'this message was sent to email address.' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __PDS_SENT_TO_EMAIL_ADDR,[l=0] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'multiple password failures' => '__TVD_PH_BODY_08,[l=1]',
                              'fees' => '__FEES,[l=1]',
                              'size' => 'BODY_ENHANCEMENT2,[l=1]',
                              'return to office' => '__BOUNCE_OOO_CB4,[l=1]',
                              'ticketed itinerary' => '__TRAVEL_ITINERARY,[l=0]',
                              'une mallette m\\303\\251tallique' => '__TRUNK_BOX,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'interna' => '__LOTTO_ADMITS_2,[l=1]',
                              '=f6verskridit gr=e4nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'business' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'dear sir' => 'DEAR_SOMETHING,[l=1] __FRAUD_IRT,[l=1]',
                              'picked' => '__RANDOM_PICK,[l=1]',
                              'priv\\303\\251' => '__HUSH_HUSH,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'transaction failed - unrepairable virus detected' => 'BAD_CREDIT,[l=1] __ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_MCQ,[l=1] __VBOUNCE_AOL,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'alkuper\\303\\244inen viesti' => '__freemail_safe_fwd,[l=1]',
                              'buy as many shares of it as i can' => '__PUMPDUMP_09,[l=1]',
                              'solicitor at law' => '__BARRISTER,[l=1]',
                              'lottery international' => '__AFF_LOTTERY,[l=0] __FRAUD_RLX,[l=1] __HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'to uplift this suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1] __THIS_AD,[l=1]',
                              'yours faithfully' => '__DECEASED,[l=1] __FRAUD_IRT,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'we have already remitted ' => '__FRAUD_WNY,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'ready for pay' => '__FEES,[l=1] __PAY_YOU,[l=1] __YOU_WON_02,[l=1] __hk_win_j,[l=1]',
                              'time offer' => 'ONE_TIME,[l=1]',
                              'este correo no puede ser considerado intrusivo' => 'NOT_SPAM,[l=1]',
                              'silent partner' => '__FRAUD_TDP,[l=1]',
                              'join thousands' => 'JOIN_MILLIONS,[l=1] __FRAUD_LTX,[l=1]',
                              'times an principal' => '__PUMPDUMP_01,[l=1]',
                              'mail address has w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1] __hk_win_b,[l=1]',
                              'charge' => '__FEES,[l=1]',
                              'courier' => '__COURIER,[l=1] __FEES,[l=1]',
                              'drugs online' => 'FREE_QUOTE_INSTANT,[l=1] ONLINE_PHARMACY,[l=1]',
                              'finance company' => '__FRAUD_IRJ,[l=0]',
                              'interest' => '__BACK_SCRATCH,[l=1]',
                              'agreed' => '__AGREED_RATIO,[l=1]',
                              'we is not spam' => 'NOT_SPAM,[l=1]',
                              'difunt' => '__DECEASED,[l=1]',
                              'registration' => '__FEES,[l=1]',
                              'repair' => 'BAD_CREDIT,[l=1]',
                              'you are receive this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'settlement' => '__LOTTO_DEPT,[l=1]',
                              'multiply an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'herede' => '__NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1]',
                              'male organ' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'proposal' => '__DEAL,[l=1] __URG_BIZ,[l=1]',
                              'leaving home' => '__STAY_HOME,[l=1]',
                              'click quota size' => 'BODY_ENHANCEMENT2,[l=1] __CLEAN_MAILBOX,[l=1]',
                              'skelaxin' => '__DRUGS_MUSCLE5,[l=1]',
                              'urgent reply' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __URG_BIZ,[l=1]',
                              'error: message content rejected' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __ADMAIL,[l=1] __VBOUNCE_SMTP,[l=1]',
                              'times your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'immediate response' => '__FRAUD_DPR,[l=1] __URG_BIZ,[l=1]',
                              'quintupling your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'extra' => 'DIET_1,[l=1] __RECEIVE_BONUS,[l=1]',
                              'you have received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'for' => '__YOU_WON_02,[l=1]',
                              'reply' => '__FRAUD_MLY,[l=1]',
                              'winning e' => '__hk_win_a,[l=1]',
                              'mail account' => '__ADMAIL,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __WEBMAIL_ACCT,[l=1] __YOU_WON_01,[l=1]',
                              'damag' => 'BAD_CREDIT,[l=1]',
                              'dear internet' => 'DEAR_SOMETHING,[l=1]',
                              'modalities' => '__FRAUD_THJ,[l=0]',
                              'sealed' => '__TRUNK_BOX,[l=1]',
                              'make your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'blocked by mailsweeper' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __VBOUNCE_MAILSWEEP2,[l=1] __YOU_WON_01,[l=1]',
                              'sement' => '__ADMITS_SPAM,[l=1]',
                              'sum pay' => '__FEES,[l=1] __PAY_YOU,[l=1] __hk_win_j,[l=1]',
                              'to your organi' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TO_YOUR_ORG,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'award notification' => '__FRAUD_FVU,[l=0] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'you\'ve receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you are receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'be greeted with' => '__RECEIVE_BONUS,[l=1]',
                              'partner website' => 'MARKETING_PARTNERS,[l=1]',
                              'tripling your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'probate' => '__WILL_LEGAL,[l=1]',
                              'd\\351funt' => '__DECEASED,[l=1]',
                              'viagra ' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] DRUG_ED_ONLINE,[l=1] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE_V,[l=1]',
                              'brought' => '__DAY_I_EARNED,[l=1]',
                              'deine zukunft zerst' => '__DESTROY_YOU,[l=1] __DRUGS_PAIN2,[l=1]',
                              'going out of your residence' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'admin team' => '__SYSADMIN,[l=1]',
                              'triple an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              '=f6verskridit gr\\344nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'strong cash flow' => '__DOS_STRONG_CF,[l=1]',
                              'this message cannot be considered spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __THIS_AD,[l=1]',
                              '\\366verskridit gr=e4nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'aise ballot' => '__HK_LOTTO_BALLOT,[l=1]',
                              'notification' => '__LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'millon u' => '__FRAUD_LTX,[l=1]',
                              'your compensation' => '__COMPENSATION,[l=1] __DECEASED,[l=1] __DOS_BODY_SAT,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_SCAM_N8,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'business partner' => '__DEAL,[l=1] __FRAUD_TDP,[l=1] __GAPPY_SALES_LEADS,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'securities company' => '__FRAUD_IRJ,[l=0]',
                              'account' => '__DORMANT_ACCT,[l=1]',
                              'abandoned' => '__DORMANT_ACCT,[l=1]',
                              'vigara' => '__DRUGS_ERECTILE2,[l=1]',
                              'monero (xmr)' => '__DOS_BODY_MON,[l=1] __MONERO_CURNCY,[l=1]',
                              'discretion' => '__HUSH_HUSH,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'not interested' => 'REMOVE_BEFORE_LINK,[l=1] __BACK_SCRATCH,[l=1]',
                              'orphelins' => '__CHARITY,[l=1]',
                              'release yourpending ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'contains forward-looking statements' => 'FORWARD_LOOKING,[l=1] __YOU_WON_02,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'financial' => '__DEAL,[l=1]',
                              'a potentially executable attachment ' => '__DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_EXIM,[l=1]',
                              'proof' => '__TRUNK_BOX,[l=1]',
                              'to remove the suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'happily announce' => '__hk_win_3,[l=1]',
                              '=f6verskridit gr=e4nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              '=e5terst\\344lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              'original message' => '__ADMAIL,[l=1] __freemail_safe_fwd,[l=1]',
                              'final day of the bonus offer' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1]',
                              'remit' => '__FRAUD_WNY,[l=1]',
                              'refinance your house' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mail just w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1] __hk_win_0,[l=1]',
                              'request' => '__URG_BIZ,[l=1]',
                              'payment' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'remov' => '__SUBSCRIPTION_INFO,[l=1]',
                              'you have received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'advertising' => '__GAPPY_SALES_LEADS,[l=1] __THIS_AD,[l=1]',
                              'online pharmacy' => 'FREE_QUOTE_INSTANT,[l=1] ONLINE_PHARMACY,[l=1] TVD_VISIT_PHARMA,[l=1]',
                              'mail account has been accessed' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ADMAIL,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __MAIL_ACCT_ACCESS1,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __WEBMAIL_ACCT,[l=1] __YOU_WON_01,[l=1]',
                              'release' => '__SUM_OF_FUND,[l=1]',
                              'steady course' => '__DOS_STEADY_COURSE,[l=1]',
                              'late' => '__DECEASED,[l=1]',
                              'profile' => '__TRAVEL_PROFILE,[l=1]',
                              'declined' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1]',
                              'prive' => '__HUSH_HUSH,[l=1]',
                              'internet draw' => '__HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1]',
                              'never hear me again' => '__NEVER_HEAR_EN,[l=0] __NOT_SCAM,[l=1]',
                              '=f6verskridit gr=e4nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'foreign account' => '__DORMANT_ACCT,[l=1] __FRAUD_JBU,[l=1] __FRAUD_JNB,[l=1] __FRAUD_TCC,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'recommend a company' => '__PUMPDUMP_06,[l=1]',
                              'you received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'your subscription' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'guarantee!' => 'BANG_GUAR,[l=1]',
                              'foreign bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_TCC,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'this message contains an html formatted message but your ema' => '__ADMAIL,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RUDE_HTML_3,[l=0] __THIS_AD,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'mail quota size' => 'BODY_ENHANCEMENT2,[l=1] __ADMAIL,[l=1] __CLEAN_MAILBOX,[l=1] __GAPPY_SALES_LEADS,[l=1] __YOU_WON_01,[l=1]',
                              'you are received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '\\366verskridit gr\\344nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'international' => '__HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'multiply your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'local' => '__SYSADMIN,[l=1]',
                              'securing the fund' => '__DEAL,[l=1] __FRAUD_WFC,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'non-accredited' => 'PREST_NON_ACCREDITED,[l=1]',
                              'records ' => '__TVD_PH_BODY_02,[l=1]',
                              'can help' => '__CAN_HELP,[l=1] __SYSADMIN,[l=1]',
                              'buy as many shares as i can' => '__PUMPDUMP_09,[l=1]',
                              'buy as many shares of it as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'i am mr' => '__FRAUD_QXX,[l=1]',
                              'securing fund' => '__FRAUD_WFC,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'made' => '__DAY_I_EARNED,[l=1]',
                              'http://docs.google.com/forms/' => '__UNSUB_GOOG_FORM,[l=1] __YOU_WON_02,[l=1]',
                              'as a foreigner' => '__FRAUD_XJR,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'confirm' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'security department' => '__FEES,[l=1] __HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1] __SECURITY_DEPT,[l=1] __TRUNK_BOX,[l=1]',
                              'war veterans' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'download your ' => '__DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'quadrupling an principal' => '__PUMPDUMP_01,[l=1]',
                              'ordinator' => '__FRAUD_RLX,[l=1]',
                              '=f6verskridit gr\\344nsen f\\303\\266r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              '\\366verskridit gr\\344nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'recommends a stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1]',
                              'concealed' => '__HUSH_HUSH,[l=1]',
                              'lucky nl number' => '__LOTTO_WIN_01,[l=1] __LUCKY_WINNER,[l=1] __hk_win_9,[l=1]',
                              '100% safe' => '__FEES,[l=1] __FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1]',
                              'united states dollars' => 'MILLION_USD,[l=1] __FRAUD_LTX,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'quadrupling an principle' => '__PUMPDUMP_01,[l=1]',
                              'certified' => '__TRUSTED_CHECK,[l=1]',
                              'lucrative' => '__LUCRATIVE,[l=1]',
                              'link to save' => 'TVD_LINK_SAVE,[l=1] __DOS_LINK,[l=1]',
                              '&#x62;&#x69;&#x74;&#x63;&#x6f;&#x69;&#x6e;' => '__BTC_OBFU_5,[l=0]',
                              ' to our affiliates' => '__WE_PAID,[l=1]',
                              'get as many shares as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '=f6verskridit gr=e4nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'tripling an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'd\\351nt' => '__DECEASED,[l=1]',
                              'administrador do sistema' => '__SYSADMIN,[l=1]',
                              'rank well on ' => '__PDS_SEO2,[l=1]',
                              'in been accessed' => '__MAIL_ACCT_ACCESS1,[l=1]',
                              'overnight' => 'DRUG_ED_ONLINE,[l=1] __FRAUD_QFY,[l=1]',
                              'weight' => 'DIET_1,[l=1]',
                              'lottery' => '__AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'pounds' => 'DIET_1,[l=1]',
                              'up click' => '__CLEAN_MAILBOX,[l=1]',
                              'check' => '__LOTTO_WIN_01,[l=1]',
                              'quintupling your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'never' => '__NOT_SCAM,[l=1]',
                              'discrete' => '__HUSH_HUSH,[l=1]',
                              'no medical exam' => 'NO_MEDICAL,[l=1]',
                              'banking laws' => 'BANKING_LAWS,[l=0]',
                              'cycl' => '__DRUGS_MUSCLE2,[l=1]',
                              ' special effort' => '__WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              ' before tomorrow' => '__PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'this offer is for united states' => '__DEAL,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              'foreign' => '__LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'reply urgently' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __URG_BIZ,[l=1]',
                              'pay' => '__FEES,[l=1] __PAY_YOU,[l=1]',
                              'attachment' => '__DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1]',
                              'bevatte bijlage besmet welke besmet was met een virus' => '__VBOUNCE_DUTCH,[l=1]',
                              'out of office' => '__BOUNCE_OOO_CB1,[l=1]',
                              'you are receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'perscr' => 'NO_PRESCRIPTION,[l=1]',
                              '.ob' => '__DOS_BODY_TICKER,[l=1]',
                              'delivery' => '__FEES,[l=1]',
                              'perfect binary option' => '__PERFECT_BINARY,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'operation' => '__FRAUD_XWW,[l=1]',
                              'triple your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'response' => '__URG_BIZ,[l=1]',
                              'rivotril' => '__DRUGS_ANXIETY9,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              ' friday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'snap up as many shares of it as i can' => '__PUMPDUMP_09,[l=1]',
                              'falecido' => '__DECEASED,[l=1]',
                              'pills' => '__PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'cklich' => '__LUCKY_WINNER,[l=1]',
                              'fraud' => '__FRAUD,[l=1]',
                              'regarding' => '__ACH_CANCELLED_04,[l=1]',
                              'you\'re received this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'intestate' => '__WILL_LEGAL,[l=1]',
                              'retrieve yourpending ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'opt' => '__SUBSCRIPTION_INFO,[l=1]',
                              'further info' => '__DEAL,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'get as many shares of it as i can' => '__PUMPDUMP_09,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'file your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'violation: clean' => '__CLEAN_MAILBOX,[l=1]',
                              'security company' => '__FEES,[l=1] __FRAUD_IRJ,[l=0] __TRUNK_BOX,[l=1]',
                              '\\366verskridit gr\\344nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'permission' => '__YOUR_PERM,[l=1]',
                              '\\33$b' => '__ISO_2022_JP_DELIM,[l=1]',
                              'compliments of the' => '__DEAL,[l=1] __FRAUD_IRT,[l=1]',
                              'aise draw' => '__HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1]',
                              'your itinerary' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TRAVEL_ITINERARY,[l=0] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'notice the winning' => '__DEAL,[l=1] __hk_win_5,[l=1]',
                              'passive income' => '__PASSIVE_INCOME,[l=1]',
                              'please reduce your ' => '__CLEAN_MAILBOX,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'automobile accident' => '__AUTO_ACCIDENT,[l=0] __DECEASED,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f=f6r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'promotional draw' => '__HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1] __THIS_AD,[l=1]',
                              'you have receive this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lengthen' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __DEAL,[l=1]',
                              'lo & incolla' => '__COPY_PASTE_IT,[l=1]',
                              'financially free' => 'FIN_FREE,[l=1] __DEAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'nigeria national' => '__FRAUD_YQV,[l=0] __HK_LOTTO_2,[l=1] __NIGERIA,[l=1]',
                              'future_mail' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'current price:' => 'CURR_PRICE,[l=1] LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1]',
                              ' contains the virus' => '__DEAL,[l=1] __VBOUNCE_VALERT,[l=1]',
                              'marketing partner' => 'MARKETING_PARTNERS,[l=1] __GAPPY_SALES_LEADS,[l=1]',
                              'this_list' => '__DEAL,[l=1] __OBFU_UNSUB_UL,[l=1] __THIS_AD,[l=1]',
                              'sea account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1]',
                              '\\303\\266verskridit gr\\344nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'you\'ve received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'confidential' => '__DECEASED,[l=1] __FRAUD_MCQ,[l=1] __HUSH_HUSH,[l=1] __URG_BIZ,[l=1]',
                              'collect' => '__RECEIVE_BONUS,[l=1]',
                              'of late president' => '__DECEASED,[l=1] __FRAUD_EZY,[l=1]',
                              'government of nigeria' => '__FRAUD_NEB,[l=0] __FRAUD_QFY,[l=1] __NIGERIA,[l=1]',
                              'you receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'llig risikofrei ist' => '__FRAUD_IOV,[l=1]',
                              'trading at such a cheap' => '__PUMPDUMP_10,[l=1]',
                              'kopieren & einf\\303\\274gen' => '__COPY_PASTE_DE,[l=0]',
                              'register' => '__SUBSCRIPTION_INFO,[l=1]',
                              'behalf' => '__OUR_BEHALF,[l=1]',
                              'premature ejaculation' => 'IMPOTENCE,[l=1]',
                              'private ' => '__FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __HUSH_HUSH,[l=1]',
                              'holding storage house' => '__FRAUD_IRJ,[l=0] __STOCK_TIP,[l=1]',
                              '\\366verskridit gr=e4nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              ' winner of our' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __hk_win_2,[l=1] __hk_win_d,[l=1]',
                              'benin' => '__BENIN,[l=1]',
                              ' to your mail' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __MAIL_ACCT_ACCESS2,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amalgamated bank' => '__FRAUD_BEP,[l=1]',
                              'congratulations to your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_7,[l=1]',
                              ' opens thursday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'respond' => '__FRAUD_MLY,[l=1]',
                              'inherited' => '__I_INHERIT,[l=1] __NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1] __YOU_INHERIT,[l=1]',
                              ' wednesday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'contact information' => '__CONTACT_ATTY,[l=1] __FRAUD_ETX,[l=1] __FRAUD_JYG,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'escolhidos aleatoria' => '__RANDOM_PICK,[l=1]',
                              'promotion date' => '__KAM_LOTTO2,[l=1] __THIS_AD,[l=1]',
                              'diese nachricht ist kein spam' => 'NOT_SPAM,[l=1] __DEAL,[l=1]',
                              'lo e incolla' => '__COPY_PASTE_IT,[l=1]',
                              'larger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'shore bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1]',
                              'calis' => '__DRUGS_ERECTILE4,[l=1]',
                              ' monday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'codicil' => '__WILL_LEGAL,[l=1]',
                              'operate' => '__FRAUD_XWW,[l=1]',
                              'account offshore' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __HK_SCAM_N15,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'live ' => 'LIVE_PORN,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f\\366r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'deal' => '__DEAL,[l=1]',
                              'central bank of' => '__FRAUD_BEP,[l=1]',
                              'file for your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'sans' => '__CHARITY,[l=1]',
                              ' bank customer' => '__STOCK_TIP,[l=1] __TVD_PH_BODY_06,[l=1]',
                              'escogidos al azar' => '__RANDOM_PICK,[l=1]',
                              'snap up as many shares of it as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'advert' => '__THIS_AD,[l=1]',
                              'accounts ' => '__DORMANT_ACCT,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f=f6r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'management team' => '__SYSADMIN,[l=1]',
                              'cilais' => '__DRUGS_ERECTILE4,[l=1]',
                              '=e5terst\\303\\244lla ditt konto' => '__VALIDATE_MBOX_SE,[l=1]',
                              'xanax' => 'DRUGS_SMEAR1,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'this is ' => '__DEAL,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_05,[l=1]',
                              'private' => '__HUSH_HUSH,[l=1]',
                              'approved' => 'TVD_APPROVED,[l=1]',
                              'you\'re receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'multiply your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'also' => '__RECEIVE_BONUS,[l=1]',
                              'number' => '__LOTTO_WIN_01,[l=1]',
                              'this offer is only for united states' => '__DEAL,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              'triple an principal' => '__PUMPDUMP_01,[l=1]',
                              'i am contacting you' => '__CONTACT_ATTY,[l=1] __CONTACT_YOU,[l=1] __FRAUD_JYG,[l=1] __FRAUD_NRG,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'attorney' => '__CONTACT_ATTY,[l=1]',
                              'subscrib' => '__SUBSCRIPTION_INFO,[l=1]',
                              'levitra' => 'DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_L,[l=1]',
                              'bequest' => '__WILL_LEGAL,[l=1]',
                              'upgrade of your account' => '__ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'seleccion aleatoria' => '__RANDOM_PICK,[l=1]',
                              'the infected attachment' => '__DEAL,[l=1] __DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_ATTACHMENT0,[l=1]',
                              'you received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '=f6verskridit gr\\303\\244nsen f=f6r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'visit your country' => '__DECEASED,[l=1] __FRAUD_IPK,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'votre' => '__YOU_ASSIST,[l=1]',
                              'box quota size' => 'BODY_ENHANCEMENT2,[l=1] __CLEAN_MAILBOX,[l=1]',
                              'you have received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pay you the sum of' => '__DEAL,[l=1] __FEES,[l=1] __HK_SCAM_S1,[l=0] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'tripling an principal' => '__PUMPDUMP_01,[l=1]',
                              'suggestion' => '__DEAL,[l=1]',
                              'my old job' => '__DOS_MY_OLD_JOB,[l=1]',
                              'total' => '__FRAUD_JYG,[l=1]',
                              'kopieren & einf\\374gen' => '__COPY_PASTE_DE,[l=0]',
                              'going out of your home' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'l$>5bz8x9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'batch number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'size automatically' => 'BODY_ENHANCEMENT2,[l=1] __CLEAN_MAILBOX,[l=1]',
                              'validate ' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              '\\366verskridit gr\\303\\244nsen f\\303\\266r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'marshal rule: inbound messages : block dangerous attachments' => '__ADMAIL,[l=1] __DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_MAILMARSHAL,[l=1]',
                              'release messages' => '__ADMAIL,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1]',
                              'paid' => '__FEES,[l=1]',
                              'erectile dysfunction' => 'IMPOTENCE,[l=1]',
                              'unexpected luck' => '__hk_win_8,[l=1]',
                              'deine' => '__DRUGS_PAIN2,[l=1]',
                              'recommended this stock' => '__DEAL,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1] __THIS_AD,[l=1]',
                              'to your white' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'son of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1]',
                              'incur' => '__FRAUD_WNY,[l=1]',
                              ' and am unable to read your message' => '__ADMAIL,[l=1] __BOUNCE_OOO_B1,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'to be removed from' => 'EXCUSE_4,[l=1] EXCUSE_REMOVE,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'pill' => '__PILL_PRICE_01,[l=1]',
                              'orphan' => '__CHARITY,[l=1]',
                              'apex bank' => '__FRAUD_BEP,[l=1]',
                              '> tvqqaamaaaaeaaaa' => '__VBOUNCE_QUOTED_EXE,[l=1]',
                              'cons\\303\\251quence' => '__YOU_WON_04,[l=1]',
                              'marfil' => '__IVORY_COAST,[l=1]',
                              'happily aannounce' => '__hk_win_3,[l=1]',
                              'or best offer' => '__FOR_SALE_OBO,[l=1]',
                              'you receiving this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'link' => '__DOS_LINK,[l=1]',
                              'shlong' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              ' to your webmail' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __MAIL_ACCT_ACCESS2,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'to your country' => '__DECEASED,[l=1] __FRAUD_IPK,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ee;r%a!<%k9-9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'quadruple your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'secr' => '__HUSH_HUSH,[l=1]',
                              'reservation' => '__TRAVEL_RESERV,[l=1]',
                              'my name is dr' => '__FRAUD_QXX,[l=1]',
                              'herdei' => '__I_INHERIT,[l=1]',
                              'you\'re received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' tomorrow open' => '__PUMPDUMP_03,[l=1]',
                              'winning information' => '__LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1] __hk_win_a,[l=1]',
                              'to regain access' => '__ACCESS_RESTORE,[l=1]',
                              'transform your daily life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lit\\303\\251' => '__HUSH_HUSH,[l=1]',
                              'meurs' => '__AM_DYING,[l=1]',
                              'quadruple an investment' => '__INVEST_MONEY,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'this offer only for usa' => '__DEAL,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              ' media group' => 'DX_TEXT_03,[l=1] __LOTTO_DEPT,[l=1]',
                              'security dept' => '__FEES,[l=1] __LOTTO_DEPT,[l=1] __SECURITY_DEPT,[l=1] __TRUNK_BOX,[l=1]',
                              'quadruple your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'download yourheld ' => '__DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'burkina' => '__BURKINA_FASO,[l=1]',
                              'you are receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'snap up as many shares as i can' => '__PUMPDUMP_09,[l=1]',
                              ' account more secure' => 'TVD_PH_7,[l=1] TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_SECURE,[l=1] __DORMANT_ACCT,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'internet sweepstake' => '__HK_LOTTO_BALLOT,[l=1]',
                              'click clean' => '__CLEAN_MAILBOX,[l=1]',
                              'download' => '__DLND_ATTACH,[l=1]',
                              'beneficial' => '__BACK_SCRATCH,[l=1]',
                              'breast' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'get as many shares as i can' => '__PUMPDUMP_09,[l=1]',
                              'we have paid ' => '__FEES,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'to_unsubscribe' => '__OBFU_UNSUB_UL,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'dorment' => '__DORMANT_ACCT,[l=1]',
                              'fiduciary agent' => '__FRAUD_FCW,[l=0] __HK_LOTTO_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'we have already paid ' => '__FEES,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'profitable' => '__DEAL,[l=1] __LUCRATIVE,[l=1] __YOUR_PROFIT,[l=1]',
                              'you are receiving this advertisement' => 'EXCUSE_24,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' thousand to our users' => '__FRAUD_LTX,[l=1] __WE_PAID,[l=1]',
                              'you have received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' before monday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              ' before friday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'ee;r%a!<%k8x9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'this offer only for united states' => '__DEAL,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              'killed' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'computer ballot' => '__HK_LOTTO_BALLOT,[l=1] __RANDOM_PICK,[l=1]',
                              'finance firm' => '__FRAUD_IRJ,[l=0]',
                              'you receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'promotional sweepstake' => '__HK_LOTTO_BALLOT,[l=1] __THIS_AD,[l=1]',
                              'you\'ve receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'murder' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'this' => '__DEAL,[l=1] __THIS_AD,[l=1]',
                              'foriegn account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __YOU_WON_02,[l=1]',
                              ' thousand' => '__FRAUD_LTX,[l=1]',
                              'vicodin' => '__DRUGS_PAIN_VICO,[l=0]',
                              'aise sweepstake' => '__HK_LOTTO_BALLOT,[l=1]',
                              'automatically reduce the ' => '__CLEAN_MAILBOX,[l=1] __DEAL,[l=1]',
                              'instant' => 'FREE_QUOTE_INSTANT,[l=1]',
                              'losing' => 'DIET_1,[l=1]',
                              'generic viagra' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] DRUG_ED_GENERIC,[l=1] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE_V,[l=1]',
                              'address directly at' => '__DOS_EMAIL_DIRECTLY,[l=1]',
                              '\\303\\266verskridit gr\\303\\244nsen f\\366r din postl=e5da' => '__MAILBOX_FULL_SE,[l=1]',
                              'foriegn bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __YOU_WON_02,[l=1]',
                              'deceased' => '__DECEASED,[l=1]',
                              '\\366verskridit gr\\344nsen f\\303\\266r din postl\\303\\245da' => '__MAILBOX_FULL_SE,[l=1]',
                              'magnanimity' => '__FRAUD_AXF,[l=0]',
                              'earliest reply' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1]',
                              'alprazolam' => '__DRUGS_ANXIETY2,[l=1]',
                              'technical error' => '__ACH_CANCELLED_03,[l=1]',
                              ' dollar bonus offer' => '__BONUS_LAST_DAY,[l=1] __RECEIVE_BONUS,[l=1]',
                              'you received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '\\303\\266verskridit gr=e4nsen f\\366r din postl\\345da' => '__MAILBOX_FULL_SE,[l=1]',
                              'dear traveller' => 'DEAR_SOMETHING,[l=1] __TRAVEL_AGENT,[l=1]',
                              ' dollars to our users' => '__WE_PAID,[l=1]',
                              'refinance your current house' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'no exercise' => 'DIET_1,[l=1]',
                              'barrister' => '__BARRISTER,[l=1] __CONTACT_ATTY,[l=1]',
                              'administration team' => '__SYSADMIN,[l=1]',
                              'caplets' => '__PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'going out of house' => '__STAY_HOME,[l=1]',
                              'oversea account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_N15,[l=1]',
                              'time promotion' => 'ONE_TIME,[l=1] __THIS_AD,[l=1]',
                              'grab as many shares as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'secure monies' => '__DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]'
                            },
           'base_orig' => {
                            '__DOS_BODY_TUE,[l=1]' => '(?i)\\btue(?:s(?:day)?)?\\b',
                            '__DOS_BODY_THU,[l=1]' => '(?i)\\bthu(?:r(?:s(?:day)?)?)?\\b',
                            '__DOS_BODY_FRI,[l=1]' => '(?i)\\bfri(?:day)?\\b',
                            '__FRAUD_MCQ,[l=1]' => '(?i)\\btransaction\\b.{1,30}\\b(?:magnitude|diplomatic|strict|absolute|secret|confiden(?:tial|ce)|guarantee)',
                            '__TRUSTED_CHECK,[l=1]' => '(?i)\\b(?:cashier\'?s?|certified)\\sche(?:ck|que)',
                            '__TO_YOUR_ORG,[l=1]' => '(?i)\\b(?:to|for) your organi[sz]ation\\b',
                            'NOT_SPAM,[l=1]' => '(?i)\\b(?:(?:this (?:e?-?mail|message)|we) (?:is not|are not|cannot be considered) Spam|ESTE CORREO NO PUEDE SER CONSIDERADO (?:INTRUSIVO|spam)|Diese Nachricht ist KEIN SPAM)',
                            '__FRAUD_JYG,[l=1]' => '(?i)\\bgive\\s+you .{0,15}(?:fund|money|total|sum|contact|percent)\\b',
                            '__NOT_DEAD_YET,[l=1]' => '(?i)\\b(?:will\\sinherit|que\\sherede|your\\sdeath|your?\\sbeing\\sdead)\\b',
                            '__IVORY_COAST,[l=1]' => '(?i)\\b(?:Cote\\s?D.Ivoire|Ivory\\s?Coast|Costa\\sde\\sMarfil)\\b',
                            '__FRAUD_XWW,[l=1]' => '(?i)\\b(?:honest(?:ly)?\\sco(?:-?operat(?:e|ion)|llaborat(?:e|ion))|ehrliche\\szusammenarbeit|sichere [kc]o+p[eo]ration|col+aboration\\swith\\sme)\\b',
                            '__HK_SCAM_N15,[l=1]' => '(?i)\\b(?:account (?:overseas?|offshore)|(?:overseas?|offshore) account)\\b',
                            '__DRUGS_ANXIETY_VAL,[l=0]' => '(?i)valium',
                            '__FRAUD_NEB,[l=0]' => '(?i)(?:government|bank) of nigeria',
                            '__DRUGS_ANXIETY9,[l=1]' => '(?i)\\brivotril\\b',
                            '__ACH_CANCELLED_02,[l=1]' => '(?i)(?:rejected|cancel+ed|declined|your)[-_ ](?:(?-i:ACH)|direct[-_ ]deposit)[-_ ](?:payment|transfer|transaction|declin(?:ed|ing))',
                            'MILLION_USD,[l=1]' => '(?i)Million\\b.{0,40}\\b(?:United States? Dollars?|USD)',
                            '__DOS_MY_OLD_JOB,[l=1]' => 'my old job',
                            '__TRTMT_DEFILED,[l=1]' => '(?i)\\bdefiled\\sall\\s(?:forms\\sof\\s)?(?:medical\\s)?treatments?\\b',
                            '__BOUNCE_OOO_B2,[l=1]' => '\\bI am currently out of the office\\b',
                            '__DLND_ATTACH,[l=1]' => '(?i)\\bdownload\\sthe\\sattach(?:ed|ment)\\b',
                            'GUARANTEED_100_PERCENT,[l=0]' => '(?i)100% GUARANTEED',
                            '__BOUNCE_NONWORKING,[l=1]' => '(?i)\\bYou have reached a non.?working address.  Please check\\b',
                            'TVD_LINK_SAVE,[l=1]' => '(?i)\\blink to save\\b',
                            'TVD_PH_SEC,[l=1]' => '(?i)\\byour .{0,40}account .{0,40}security',
                            '__LARGE_PERCENT_AFTER,[l=1]' => '(?i)\\d{3}% after',
                            '__FRAUD_WFC,[l=1]' => '(?i)\\bsecur(?:e|ing) (?:the )?(?:funds?|monies)\\b',
                            '__FRAUD_UUY,[l=1]' => '(?i)\\blegitimate business(?:es)?\\b',
                            '__BOUNCE_OOO_B1,[l=1]' => '\\bI ?.m away until .{10,20} and am unable to read your message\\b',
                            '__TVD_PH_BODY_02,[l=1]' => '(?i)\\brecords (?:[a-z_,-]+ )+?(?:feature|(?:a|re)ward)',
                            '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]' => '(?i)\\b(?:(?:[dr]e-?)?activat[a-z]*|(?:re-?)?validate|secure|restore|confirm|update|suspend) (?!your)(?:[a-z_,-]+ )+?accounts?\\b',
                            '__BENIN,[l=1]' => '(?i)\\bb(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])nin\\b',
                            '__TRAVEL_ITINERARY,[l=0]' => '(?i)(?:travel|ticketed|your|current) itinerary',
                            '__FRAUD_PVN,[l=0]' => '(?i)as the beneficiary',
                            '__VBOUNCE_STRIP_ATTACH,[l=1]' => '\\bhas stripped one or more attachments from the following message\\b',
                            '__FB_TOUR,[l=1]' => '(?i)\\btour',
                            'NA_DOLLARS,[l=1]' => '(?i)\\b(?:\\d{1,3})?Million\\b.{0,40}\\b(?:Canadian Dollar?s?|US\\$|U\\.? ?S\\.? Dollar)',
                            '__FRAUD_ETX,[l=1]' => '(?i)\\byour\\b[^.]{0,99}\\b(?:contact (?:details|information)|private (?:e?[- ]?mail|telephone|tel|phone|fax))\\b',
                            '__FRAUD_FBI,[l=1]' => '(?i)\\bdisburs',
                            '__PLS_REVIEW,[l=1]' => '(?i)\\b(?:please|kindly)\\s(?:(?:re)?view|see)(?:\\s\\w+)?\\sattach(?:ed|ment)\\b',
                            '__FOR_SALE_LTP,[l=1]' => '(?i)00\\.? (?:less 10%|LTP)',
                            '__VBOUNCE_MAILSWEEP2,[l=1]' => '(?i)\\bblocked by Mailsweeper\\b',
                            '__COPY_PASTE_SE,[l=0]' => '(?i)kopiera den och klistra in',
                            '__FRAUD_FCW,[l=0]' => '(?i)fiduciary agent',
                            '__RUDE_HTML_3,[l=0]' => '(?i)This message contains an HTML formatted message but your email client does',
                            '__LOTTO_VERIFY,[l=1]' => '(?i)\\bpromo\\sverification',
                            '__ISO_2022_JP_DELIM,[l=1]' => '\\e\\$B',
                            '__WIDOW,[l=1]' => '(?i)\\b(?:widow(?:e[rd])\'?s?|veuve)\\b',
                            'SHORT_TERM_PRICE,[l=1]' => '(?i)short\\W+term\\W+(target|projected)(\\W+price)?',
                            '__BTC_OBFU_5,[l=0]' => '(?i)&#x62;&#x69;&#x74;&#x63;&#x6F;&#x69;&#x6E;',
                            '__DRUGS_PAIN11,[l=1]' => '(?i)\\bzebutal\\b',
                            '__FOR_SALE_PRC_100K,[l=1]' => '(?i)\\bprice:? \\$\\d\\d\\d,\\d\\d\\d',
                            '__DRUGS_PAIN_FIO,[l=0]' => '(?i)fioricet',
                            '__FRAUD_IPK,[l=1]' => '(?i)\\b(?:in|to|visit) your country\\b',
                            '__NEXT_OF_KIN,[l=1]' => '(?i)\\bnext[-\\s]of[-\\s]kin\\b',
                            '__FRAUD_ZFJ,[l=1]' => '(?i)\\b(?:wife|son|brother|daughter) of the late\\b',
                            '__DORMANT_ACCT,[l=1]' => '(?i)\\b(?:(?:dormant|abandoned|left\\s?over)\\s(?:account|fund|transaction|sum|deposit)|fonds\\sdorment)',
                            '__ACCESS_REVOKE,[l=1]' => '(?i)(?:(?:temporary|permanent) (?:de-?activation|removal) of your (?:\\w{1,30} )?(?:access|account)|Ihre Kreditkarte wird gesperrt)',
                            '__PDS_OFFER_ONLY_AMERICA,[l=0]' => '(?i)This offer (?:is )?(?:only )?for (United States|USA)',
                            '__DRUGS_ERECTILE_C,[l=1]' => '(?i)\\bCialis(?!\\xc3\\xa9|\\xe9)\\b',
                            '__HK_SCAM_S1,[l=0]' => '(?i)pay you the sum of',
                            '__FRAUD_RLX,[l=1]' => '(?i)lott(?:o|ery) (?:co,?ordinator|international)',
                            '__FRAUD_PTX,[l=1]' => '(?i)\\b(?:ass?ass?inat(?:ed|ion)|murder(?:e?d)?|poison(?:e?d)?|kill(?:ed|ing|ers)\\b[^.]{0,99}\\b(?:war veterans|rebels?)|les tueurs)\\b',
                            '__CONTACT_YOU,[l=1]' => '(?i)\\b(?:contact(?:ing)\\syou|vous\\scontacter?)\\b',
                            'IMPOTENCE,[l=1]' => '(?i)\\b(?:impotence (?:problem|cure|solution)|Premature Ejaculation|erectile dysfunction)',
                            '__HK_SCAM_S25,[l=1]' => '(?i)\\bbank (?:in|of) ghana',
                            '__DOS_BODY_TICKER,[l=1]' => '\\b[A-Z]{4}\\.(?:OB|PK)\\b',
                            '__DOS_BODY_WED,[l=1]' => '(?i)\\bwed(?:nesday)?\\b',
                            '__hk_win_n,[l=1]' => '(?i)\\bcollect your prize',
                            '__DECEASED,[l=1]' => '(?i)\\b(?:the|my|your|der|du|le|meu?)\\s(?:deceased|late|verstorbenen|d(?:i|e|=E9|[\\xe9]|[\\xc3][\\xa9])funto?|d(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])nt|falecido)\\b',
                            'TVD_QUAL_MEDS,[l=1]' => '(?i)\\bquality med(?:ication)?s\\b',
                            '__COPY_PASTE_IT,[l=1]' => '(?i)copia(r?)lo (e|\\&) incolla(r?)lo',
                            '__VBOUNCE_ATT_QUAR,[l=1]' => '\\bThe attachment was quarantined\\b',
                            '__DOS_BODY_SAT,[l=1]' => '(?i)\\bsat(?:day)?\\b',
                            'DRUG_ED_SILD,[l=1]' => '(?i)\\bsildenafil\\b',
                            '__TRAVEL_AGENT,[l=1]' => '(?i)\\btravel\\sagen(?:t|cy)\\b',
                            '__PERFECT_BINARY,[l=1]' => '(?i)\\bperfect binary option\\b',
                            '__DOS_TAKING_HOME,[l=1]' => 'Taking home \\d (?:digit level|figures) in \\d{1,2} months',
                            '__TRAVEL_RESERV,[l=1]' => '(?i)\\b(?:reservation\\s(?:confirmed|number)|travel\\sreservations?)\\b',
                            '__PUMPDUMP_07,[l=1]' => '(?i)\\b(?:buy|grab it) for (?:around |about |less than )?\\d+ cents\\b',
                            '__VBOUNCE_GUIN,[l=1]' => 'message contains file attachments that are not permitted',
                            '__ACCOUNT_SECURE,[l=1]' => '(?i)\\b(?:make your (?:"?[^\\@\\s]+\\@\\S+"? |e-?mail )?account more secure|Ihre Kreditkarte weist einige Sicherheitsprobleme)\\b',
                            '__RECEIVE_BONUS,[l=1]' => '(?i)\\byou(?:\'ll)?(?: also| will)* (?:rec[ei]*ve|get|earn|collect|be (?:awarded|handed|remitted|given|paid|(?:greeted|welcomed|started) with)) (?:an? )?(?:gift|bonus|extra)(?: of|:)? \\$[\\d,]+',
                            '__hk_win_i,[l=1]' => '(?i)\\bfunds? transfer',
                            '__AFR_UNION,[l=1]' => '(?i)\\bafrican\\sunion\\b',
                            '__TRANSFORM_LIFE,[l=1]' => '(?i)\\b(transform|change) your (?:daily )?life(?:style)?\\b',
                            '__FRAUD_NRG,[l=0]' => '(?i)i am contacting you',
                            '__hk_win_l,[l=1]' => '(?i)\\b(?:make|file) (?:for )?your claim',
                            '__ADULTDATINGCOMPANY_BODY,[l=1]' => '(?i)\\bAdultDatingCompany\\b',
                            'BANG_OPRAH,[l=1]' => '(?i)\\boprah!',
                            '__FRAUD_GBW,[l=1]' => '(?i)god gives .{1,10}second chance',
                            '__DESTROY_YOU,[l=1]' => '(?i)\\b(?:destroy\\syou|deine Zukunft zerst\\S{1,3}ren)',
                            '__FRAUD_AON,[l=1]' => '(?i)\\b(?:confidential|private|alternate|alternative) (?:(?:e-? *)?mail)\\b',
                            '__TVD_PH_BODY_07,[l=1]' => '(?i)\\bguarantee the safety of your (?:[a-z_,-]+ )*?account',
                            '__BARRISTER,[l=1]' => '(?i)\\b(?:barrister|solicitor at law|barr\\.)',
                            '__BURKINA_FASO,[l=1]' => '(?i)\\bburkina\\s?faso\\b',
                            '__ADMITS_SPAM,[l=1]' => '(?i)\\bth(?:e[- ]+above|is)(?:\\?+s|[- ]+is)[- ]+(?:intended[- ]+as[- ]+)?an?[- ]+(?:e-?mail[- ]+)?[a@]dvert[i1l]sement\\b',
                            '__FRAUD_EZY,[l=1]' => '(?i)\\b(?:of|the) late president\\b',
                            '__FRAUD_IOV,[l=1]' => '(?i)\\b(?:no risks?|risky?[- ]{0,3}free|free of risks?|100% safe|v\\S{1,3}llig Risikofrei ist)\\b',
                            '__DOS_BODY_MON,[l=1]' => '(?i)\\bmon(?:day)?\\b',
                            '__AGREED_RATIO,[l=1]' => '(?i)\\b(?:agreed|sharing)\\s(?:ratios?|percent\\w+)\\b',
                            '__RUDE_HTML_4,[l=1]' => '(?i)Your mailer do not support HTML messages. Switch to a better mailer',
                            '__DRUGS_DIET3,[l=1]' => '(?i)\\bbontril\\b',
                            '__FRAUD_THJ,[l=0]' => '(?i)modalit(?:y|ies)',
                            '__DOS_MEET_EACH_OTHER,[l=1]' => '(?:meet each other|[Mm]ay ?be we can meet)',
                            '__FRAUD_TCC,[l=0]' => '(?i)foreign (?:offshore )?(?:bank|account)',
                            '__ACH_CANCELLED_04,[l=1]' => '(?i)\\bregarding[-_ ]your[-_ ]direct[-_ ]deposit[-_ ]via[-_ ](?-i:ACH)',
                            'BANG_GUAR,[l=1]' => '(?i)\\bguaranteed?\\!',
                            '__YOUR_PERM,[l=1]' => '(?i)\\byour\\spermission\\b',
                            '__PUMPDUMP_01,[l=1]' => '(?i)\\b(?:times|multiply|tripl(?:e|ing)|quadrupl(?:e|ing)|quintupl(?:e|ing)) (?:your|an) (?:princip(?:al|le)|investment)\\b',
                            '__DBLCLAIM,[l=1]' => 'avoid double claiming',
                            'CURR_PRICE,[l=1]' => '\\bCurrent Price:',
                            '__UN,[l=1]' => '(?i)\\bunited\\snations?\\b',
                            'STRONG_BUY,[l=0]' => '(?i)strong buy',
                            'REFINANCE_YOUR_HOME,[l=1]' => '(?i)\\brefinance your(?: current)? (?:home|house)\\b',
                            'ONLINE_PHARMACY,[l=1]' => '(?i)\\bonline pharmacy|\\b(?:drugs|medications) online',
                            '__CASHPRZ,[l=1]' => 'cash prize of',
                            '__hk_win_m,[l=1]' => '(?i)\\br.clamation de votre prix',
                            '__DOS_DROP_ME_A_LINE,[l=1]' => 'Drop me a line at',
                            'BILLION_DOLLARS,[l=1]' => '[BM]ILLION DOLLAR',
                            '__FOR_SALE_PRC_10K,[l=1]' => '(?i)\\bprice:? \\$\\d\\d,\\d\\d\\d',
                            '__THEY_INHERIT,[l=1]' => '(?i)\\b(?:inherit\\sth(?:e|is)\\smoney|herede\\sest[ea]\\sdinero)\\b',
                            '__DRUGS_PAIN_VICO,[l=0]' => '(?i)vicodin',
                            '__MAILBOX_FULL_SE,[l=1]' => '(?i)(?:\\b=F6|[\\xf6]|[\\xc3][\\xb6])verskridit gr(?:=E4|[\\xe4]|[\\xc3][\\xa4])nsen f(?:=F6|[\\xf6]|[\\xc3][\\xb6])r din postl(?:=E5|[\\xe5]|[\\xc3][\\xa5])da\\b',
                            '__WILL_LEGAL,[l=1]' => '(?i)\\b(?:codicil|last\\stestament|probate|executor|intestate|bequest|mandamus)\\b',
                            '__ACH_CANCELLED_03,[l=1]' => '(?i)\\bwire[-_ ]?(?:payment|transfer|transaction)[-_ ](?:(?:was|is)[-_ ])?(?:rejected|cancel+ed|declined|disabled|not[-_ ]accepted|(?:technical )?error)',
                            '__WE_PAID,[l=1]' => '(?i)\\bwe have (?:already )?(?:paid|sent|remitted|issued) \\$?\\d+(?:,\\d+)* (?:thousand )?(?:dollars )?to our (?:users|subscribers|members|clients|affiliates|partners)\\b',
                            '__SCAM,[l=1]' => '(?i)\\bscam(?:m?e[dr])?s?\\b',
                            '__SUSPICION_LOGIN,[l=1]' => '(?i)\\bsuspicion login\\b',
                            'DEAR_SOMETHING,[l=1]' => '(?i)\\bDear (?:IT\\W|Internet|candidate|sirs?|madam|investor|travell?er|car shopper|web)\\b',
                            '__PUMPDUMP_06,[l=1]' => '(?i)\\brecommend(?:ed|s)? (?:a|this) (?:company|stock)\\b',
                            '__DRUGS_MUSCLE2,[l=1]' => '(?i)\\b_{0,3}cycl[o0\\xF2-\\xF6]b[e3\\xE8-\\xEB]nz[a4\\xE0-\\xE6@]pr[i1!|l\\xEC-\\xEF]n[e3\\xE8-\\xEB]_{0,3}(?:\\b|\\s)',
                            '__FRAUD_YWW,[l=1]' => '(?i)\\bfurnish you with\\b',
                            '__DRUGS_DIET5,[l=1]' => '(?i)\\bdiethylpropion\\b',
                            '__GHANA,[l=1]' => '(?i)\\bghana\\b',
                            '__COMPENSATION,[l=1]' => '(?i)\\b(?:compensat(?:e|ion)|recompensed?|ausgleich)\\b',
                            '__DRUGS_PAIN_VIOXX,[l=0]' => '(?i)vioxx',
                            'MORE_SEX,[l=1]' => '(?i)increased?.{0,9}(?:sex|stamina)',
                            '__FRAUD_YPO,[l=0]' => '(?i)the total sum',
                            '__MY_FORTUNE,[l=1]' => '(?i)\\b(?:my|his|her)\\s(?:fortune|heritage)\\b',
                            '__HK_SCAM_N8,[l=1]' => '(?i)\\byour compensation\\b',
                            '__BACK_SCRATCH,[l=1]' => '(?i)\\bmutual+y?\\s(?:benefi(?:t|cial)|interest)\\b',
                            '__FRAUD_BGP,[l=1]' => '(?i)\\battached to ticket number\\b',
                            '__DRUGS_DIET_PHEN,[l=1]' => '(?i)\\bphentermine\\b',
                            '__BOUNCE_OOO_CB4,[l=1]' => '(?i)\\breturn to (?:the )?office\\b',
                            '__VBOUNCE_AMAVISD2,[l=1]' => '\\bV I R U S\\b',
                            '__YOUR_CONSIGNMENT,[l=1]' => '(?i)\\b(?:received?|pa(?:y|id)|sen[dt]|h[oe]ld|delay(?:ed)?|impound(?:ed)?|released?|ship(?:ped)?)\\syour(?:\\s\\w+)?\\sconsignment\\b',
                            '__AUTO_ACCIDENT,[l=0]' => '(?i)auto(?:mobile)? accident',
                            '__PILL_PRICE_01,[l=1]' => '(?i)(?=[\\d .f])(?:free|[\\d .]{3}(?:/|per|each)) ?(?=[ptc])(?:pill|tablet|cap(?:sule|let))s?\\b',
                            '__DRUGS_ANXIETY8,[l=1]' => '(?i)\\bklonopin\\b',
                            '__TVD_PH_BODY_ACCOUNTS_PRE,[l=1]' => '(?i)\\baccounts? (?:[a-z_,-]+ )+?(?:record[a-z]*|suspen[a-z]+|notif(?:y|ication)|updated|verifications?|credited)\\b',
                            '__DOS_BODY_SUN,[l=1]' => '(?i)\\bsun(?:day)?\\b',
                            '__BOUNCE_OOO_CB1,[l=1]' => '(?i)\\bout of (?:the )?office\\b',
                            '__TVD_PH_BODY_03,[l=1]' => '(?i)\\byou(?:\'ve| have) been (?:[a-z_,-]+ )+?payment',
                            '__BANK_DRAFT,[l=1]' => '(?i)\\bbank\\sdraft',
                            'LOOPHOLE_1,[l=1]' => '(?i)loop-?hole in the banking',
                            'DRUGS_SMEAR1,[l=1]' => '(?i)(?:Viagra|Valium|Xanax|Soma|Cialis){2}',
                            '__FOR_SALE_OBO,[l=1]' => '(?i)\\bor best offer\\b',
                            '__LOTTO_DEPT,[l=1]' => '(?i)\\b(?:claim(?:s|ing)?(?:\\sprocessing)?|fiducia\\w+|reimbursement|(?:international|foreign|win+ing)(?:\\s(?:rem+it+ance|settlement|payment|award))+|payment|award|compensation|lot+ery)(?:\\s\\w+)?\\s?(?:department|dept|unit|group|committee|bureau)',
                            'NOT_ADVISOR,[l=0]' => '(?i)not a registered investment advisor',
                            '__FRAUD_UOQ,[l=0]' => '(?i)vital documents',
                            '__ACCOUNT_ERROR,[l=1]' => '(?i)\\b(?:your account (?:is|appears to be) (?:incorrect|missing|in error|invalid))\\b',
                            '__FAILED_LOGINS,[l=1]' => '(?i)unsuc+es+ful log-?[io]n at+empts',
                            'DRUG_ED_GENERIC,[l=1]' => '\\bGeneric Viagra\\b',
                            '__CONTACT_ATTY,[l=1]' => '(?i)\\bcontact(?:er)?\\s(?:my|(?:de\\s)?mon)\\s(?:barrister|attou?rney|lawyer|avocat|gestionnaire)\\b',
                            'EM_ROLEX,[l=1]' => '(?i)[^\\s\\w.]rolex',
                            '__VALIDATE_MBOX_SE,[l=1]' => '(?i)(?:\\b=E5|[\\xe5]|[\\xc3][\\xa5])terst(?:=E4|\\xe4|[\\xc3][\\xa4])lla ditt konto\\b',
                            '__COPY_PASTE_FR,[l=0]' => '(?i)le copier (et le|\\+) coller',
                            '__FRAUD_IRT,[l=1]' => '(?i)\\b(?:compliments? of the|dear friend|dear sir|yours faithfully|season\'?s greetings)\\b',
                            '__AM_DYING,[l=1]' => '(?i)\\b(?:am\\s(?:\\S+\\s)?dying|terminally\\sill|cancer|en\\sphase\\sterminale|(?:become|is|devenu|maladie)\\sincurable|que\\sje\\smeurs)\\b',
                            'GTUBE,[l=1]' => 'XJS\\*C4JDBQADN1\\.NSBN3\\*2IDNEN\\*GTUBE-STANDARD-ANTI-UBE-TEST-EMAIL\\*C\\.34X',
                            '__FRAUD_SNT,[l=1]' => '(?i)\\blocate(?: .{1,20})? extended relative',
                            'DEAR_BENEFICIARY,[l=1]' => '(?i)\\b(?:De[ae]r\\s|At+(?:ention|n):?\\s?)(?:\\S+\\s)?Ben[ei]ficiary\\b',
                            'TVD_VISIT_PHARMA,[l=1]' => '(?i)Online Ph.rmacy',
                            '__hk_win_0,[l=1]' => '(?i)\\byour? e-?mail just w[oi]n',
                            '__BOUNCE_NO_RESEND,[l=1]' => '\\bPlease do not resend your original message\\.',
                            '__FB_COST,[l=1]' => '(?i)\\bcost\\b',
                            '__VBOUNCE_AOL,[l=1]' => 'TRANSACTION FAILED - Unrepairable Virus Detected. ',
                            '__hk_win_o,[l=1]' => '(?i)\\bclarification and procedure',
                            '__VBOUNCE_REJ_FILT,[l=1]' => 'Reason: Rejected by filter',
                            '__FRAUD_ULK,[l=1]' => '(?i)\\baffidavits?\\b',
                            '__DEAL,[l=1]' => '(?i)\\b(?:(?:business|financial|this|the|mutual|die(?:se)?r?|cette|profitable)\\s(?:deal|transa[ck]tion|proposal|off[er]{2}|venture|suggestion|partnership)|your\\spartnership)',
                            '__PUMPDUMP_04,[l=1]' => '(?i)\\bmake you (?:big bucks|hundreds|thousands)\\b',
                            '__WEBMAIL_ACCT,[l=1]' => '(?i)\\byour web ?mail account',
                            '__FRAUD_IOU,[l=1]' => '(?i)\\b(?:no risks?|risk-? *free|free of risks?|100% safe)\\b',
                            '__PAY_YOU,[l=1]' => '\\bpay\\syou\\b',
                            'EMRCP,[l=1]' => '(?i)\\bExcess (?:Maximum )?Return Capital (?:Profits?|Funds?)\\b',
                            '__NOT_SCAM,[l=1]' => '(?i)\\b(?:not\\sa\\sscam|(?:not|never)\\sscam\\syou)\\b',
                            '__PILL_PRICE_02,[l=1]' => '(?i)(?=[ptc])(?:pill|tablet|cap(?:sule|let))s[-= :]{1,5}\\$?[\\d .]{3}',
                            '__I_INHERIT,[l=1]' => '(?i)\\b(?:I|eu)\\s[a-z\\s]{0,30}(?:inherited|herdei)\\b',
                            'TVD_SECTION,[l=1]' => '(?i)\\bSection (?:27A|21B)',
                            '__DRUGS_ERECTILE2,[l=1]' => '(?i)\\bV(?:agira|igara|iaggra|iaegra)\\b',
                            '__JAPANESE_UCE_BODY,[l=1]' => '(?:L\\$>5Bz|EE;R%a!<%k)(?:8x|9-)9p',
                            '__FRAUD_IRJ,[l=0]' => '(?i)(?:finance|holding|securit(?:ies|y)) (?:company|firm|storage house)',
                            '__FRAUD_JNB,[l=1]' => '(?i)\\boperat(?:e|ing)\\b[^.]{0,99}\\b(?:for(?:ei|ie)gn|off-? ?shore|over-? ?seas?) (?:bank )?accounts?\\b',
                            '__VBOUNCE_AVREPORT0,[l=0]' => '(?i)(antivirus system report|the antivirus module has|illegal attachment|Unrepairable Virus Detected)',
                            '__DOS_STEADY_COURSE,[l=1]' => '(?i)\\bsteady (?:and increasing )?course\\b',
                            'MILLION_HUNDRED,[l=1]' => '(?i)Million\\s+\\S+\\s+Hundred',
                            '__PASSWORD_EXP_CLUMSY,[l=1]' => '(?i)\\bpassword is due for expiration yesterday\\b',
                            '__FRAUD_AUM,[l=1]' => '(?i)\\bthe desk of\\b',
                            '__RELEASE_MESSAGES,[l=1]' => '(?i)\\b(?:release messages|(?:retrieve|release|download) your(?: undelivered|unreceived|held|pending)? e?-?mails|(?:e?-?mails|messages).{1,20}download them now)\\b',
                            '__FRAUD_QXX,[l=1]' => '(?i)\\b(?:my name is|i am) (?:mrs?|engr|barrister|dr|prince(?:ss)?)[. ]',
                            '__hk_win_d,[l=1]' => '(?i)\\bcategory (?:\\S{0,5} )?winner of our',
                            '__RUDE_HTML_2,[l=1]' => '(?i)not support the display of HTML. Please view this message in a different',
                            '__OBFU_UNSUB_UL,[l=1]' => '(?:click_here|remove_your|our_e?mail|this_list|to_unsubscribe|future_e?mail|our_list)',
                            '__ACCESS_RESTORE,[l=1]' => '(?i)\\bto (?:(?:restore|regain) access|(?:remove|uplift) (?:the|this) suspens|continue using your (?:account|online|mailbox)|zugreifen wiederhergestellt)',
                            'TVD_INCREASE_SIZE,[l=1]' => '(?i)\\bsize of .{1,20}(?:penis|dick|manhood)',
                            '__YOU_ASSIST,[l=1]' => '(?i)\\b(?:your\\sas+istan(?:ce|t)|votre\\s(?:as+istance|aide))\\b',
                            '__ADMAIL,[l=1]' => '(?i)(?:\\b|_)ad-?(?:mail|message)s?(?:\\b|_)',
                            '__PDS_SENT_TO_EMAIL_ADDR,[l=0]' => '(?i)This message was sent to Email Address\\.',
                            '__DOS_FIN_ADVANTAGE,[l=1]' => '(?i)\\bfinancial advantage',
                            'CUM_SHOT,[l=1]' => '(?i)\\bcum[ -]?shots?\\b',
                            'DRUG_ED_CAPS,[l=1]' => '\\b(?:CIALIS|LEVITRA|VIAGRA)',
                            '__VBOUNCE_DUTCH,[l=1]' => 'bevatte bijlage besmet welke besmet was met een virus',
                            '__HK_SCAM_N2,[l=1]' => '(?i)\\bnext of kin\\b',
                            '__SUBSCRIPTION_INFO,[l=1]' => '(?i)\\b(?:e?newsletters?|(?:un)?(?:subscrib|register)|you(?:r| are) subscri(?:b|ption)|opt(?:.|ing)?out\\b|further info|you do ?n[o\']t w(?:ish|ant)|remov\\w{1,3}.{1,9}\\blists?\\b|to your white.?list)',
                            'FREE_QUOTE_INSTANT,[l=1]' => '(?i)free.{0,12}(?:(?:instant|express|online|no.?obligation).{0,4})+.{0,32}\\bquote',
                            '__LUCKY_WINNER,[l=1]' => '(?i)\\b(?:lucky|gl.cklich(?:en)?|afortunados)\\s(?:(?:ge)?win+ers?|ganador(?:es)?|individuals?)\\b',
                            '__HK_LOTTO_2,[l=1]' => '(?i)\\blot(?:eri[ej]|t(?:ery|o)) ?(?:(?:inter)?national|foundation|mercato|univers|euro ?million|e-?mail|euro-pw|bill ?gates|swiss|prestige|cristal|am.ricaine|coca.?cola|fiduciary|department)',
                            '__HK_SCAM_N3,[l=1]' => '(?i)\\bdirect telephone numbers?\\b',
                            '__PDS_EXPIRATION_NOTICE,[l=1]' => '(?i)\\bexpiration (notice|alert|date)\\b',
                            '__SUM_OF_FUND,[l=1]' => '(?i)\\b(?:sum|release|freigabe)\\s(?:of|der)\\s(?:amount|fund|investment|mittel)\\b',
                            '__KAM_LOTTO2,[l=1]' => '(?is)((ticket|serial|lucky) number|secret pin ?code|batch number|reference number|promotion date)',
                            '__YOU_WON_04,[l=1]' => '(?i)\\bqu[ei]\\s?(?:vous (?:[\\xc3][\\xaa]|=C3=AA|[\\xea]|e)tes\\s?gagnant|en\\scons(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])quence\\sgagne)\\b',
                            '__AFF_LOTTERY,[l=0]' => '(?i)(?:lottery|winner)',
                            'MONEY_BACK,[l=0]' => '(?i)money back guarantee',
                            'INVESTMENT_ADVICE,[l=1]' => '(?i)\\binvestment advice',
                            '__FB_S_STOCK,[l=1]' => '(?i)\\bstock',
                            '__HK_LOTTO_STAATS,[l=1]' => '(?i)\\bstaatsloteri',
                            '__FRAUD_XJR,[l=0]' => '(?i)(?:who was a|as a|an? honest|you being a|to any) foreigner',
                            '__DOS_PERSONAL_EMAIL,[l=1]' => 'personal email at',
                            '__DRUGS_ERECTILE4,[l=1]' => '(?i)\\bC(?:alis|ilias|ilais)\\b',
                            '__THIS_AD,[l=1]' => '(?i)(?:\\b|_)this[- _]+(?:ad(?:vert[i1l]sement)?|promo(?:tion)?)s?(?:\\b|_)',
                            '__DRUGS_DIET4,[l=1]' => '(?i)\\bphendimetrazine\\b',
                            '__YOUR_BANK,[l=1]' => '(?i)\\byour?\\s(?:full\\s)?bank(?:ing)?\\sinformations?\\b',
                            'JOIN_MILLIONS,[l=1]' => '(?i)\\bjoin (?:millions|thousands)\\b',
                            '__TVD_PH_BODY_04,[l=1]' => '(?i)\\bfunds? (?!transfer from)(?!from)(?!in)(?!via)(?:[a-z_,-]+ )+?to your (?:[a-z_,-]+ )*?account',
                            '__ACCOUNT_UPGRADE,[l=1]' => '(?i)\\b(?:upgrade (?:of )your (?:account|access)|your (?:access|account) is[\\w\\s]{0,40}being upgraded|Weiter zur Aktualisierung)\\b',
                            '__EARLY_DEMISE,[l=1]' => '(?i)\\buntimely\\sdeath\\b',
                            '__RANDOM_PICK,[l=1]' => '(?i)\\b(?:random(?:ly)?\\s(?:\\w+\\s)?(?:select(?:ion|ed)|pick(?:ed)?|computer)|(?:select|pick)ed\\s(?:at\\s)?random(?:ly)?|(?:esco(?:g|lh)idos|seleccion) (?:aleatoria(?:mente)?|al azar))\\b',
                            '__COURIER,[l=1]' => '(?i)\\bcourier\\s(?:company|service)\\b',
                            '__COPY_PASTE_ES,[l=0]' => '(?i)copiarlo y pegarlo',
                            '__LOTTO_WIN_01,[l=1]' => '(?i)\\bwin+ing\\s(?:prize|number|notification|draw|check|cheque|details|information|payment)',
                            '__freemail_safe_fwd,[l=1]' => '(?i)---\\s?(?:(?:Forwarded|Original) message|Alkuper(?:\\xe4|\\xc3\\xa4)inen viesti)',
                            '__FRAUD_TDP,[l=1]' => '(?i)\\b(?:business partner(?:s|ship)?|silent partner(?:s|ship)?)\\b',
                            '__DAY_I_EARNED,[l=1]' => '(?i)day,?\\sI\\s(?:earned|got|received|made|brought\\sin)\\s\\$\\s?\\d{3}',
                            '__BOUNCE_OOO_CB3,[l=1]' => '(?i)\\bolen lomalla\\b',
                            '__DRUGS_MUSCLE5,[l=1]' => '(?i)\\bskelaxin\\b',
                            '__TVD_PH_BODY_01,[l=1]' => '(?i)\\baccount .{0,20}placed? [io]n restricted status',
                            '__DRUGS_ANXIETY_XAN,[l=1]' => '(?i)xan[ae]x',
                            '__VBOUNCE_SMTP,[l=1]' => 'host \\S+ said: 5\\d\\d\\s+Error: Message content rejected',
                            '__FRAUD_LTX,[l=1]' => '(?i)\\bmilli?on (?:.{1,25} thousand\\s*)?(?:(?:united states|u\\.?s\\.?) dollars|(?i:U\\.?S\\.?D?))\\b',
                            'DEAR_WINNER,[l=1]' => '(?i)\\bdear.{1,20}winner',
                            '__FRAUD_MQO,[l=0]' => '(?i)foreign (?:business partner|customer)',
                            '__LOTTO_ADMITS_2,[l=1]' => '(?i)\\b(?:free)?(?:lot(?:to|tery|erie)|sweepstakes)\\s(?:(?:inter)?na[tz]ional|department|bureau|group|award|microsoft)',
                            '__STAY_HOME,[l=1]' => '(?i)\\b(?:going out of|leaving)(?: your)? (?:home|house|residence)\\b',
                            '__FRAUD_WDR,[l=1]' => '(?i)\\bprivate lawyer\\b',
                            '__PUMPDUMP_10,[l=1]' => '(?i)\\btrading at (?:such )?a (?:bargain|cheap|low)\\b',
                            'EXCUSE_REMOVE,[l=1]' => '(?i)to be removed from.{0,20}(?:mailings|offers)',
                            '__SYSADMIN,[l=1]' => '(?i)\\b(?:help?[- ]?desk|(?:(?:web ?)?mail ?|sys(?:tem )?)admin(?:istrator)|local[- ]host|(?:support|upgrade|management|security|admin(?:istrat(?:or|ion))?) (?:team|center)|message from administrator|university mail server copyright|suporte t(?:=E9|[\\xe9]|[\\xc3][\\xa9])cnico|administrador do sistema)\\b',
                            '__LUCRATIVE,[l=1]' => '(?i)\\b(?:lucrative|profitable|tr[\\xe8]s\\ssalutaire)\\b',
                            'TVD_APPROVED,[l=1]' => '(?i)you.{1,2}re .{0,20}approved',
                            '__hk_win_c,[l=1]' => '(?i)\\bune adresse e-?mail sur internet',
                            '__TVD_PH_BODY_05,[l=1]' => '(?i)\\bthis is (?:[a-z_,-]+ )+?protect (?:[a-z_,-]+ )+?your',
                            'EXCUSE_4,[l=1]' => '(?i)To Be Removed,? Please',
                            '__NIGERIA,[l=1]' => '(?i)\\bnigeria\\b',
                            '__DRUGS_ERECTILE_V,[l=1]' => '(?i)\\bViagra\\b',
                            '__FRAUD_DPR,[l=1]' => '(?i)\\b(?:(?:respond|reply) (?:urgently|immediately)|(?:urgent|immediate|earliest) (?:reply|response))\\b',
                            '__TVD_PH_BODY_06,[l=1]' => '(?i)Dear [a-z]+ bank (?:member|customer)',
                            '__hk_win_2,[l=1]' => '(?i)\\battn.{0,10}winner',
                            '__MONERO_CURNCY,[l=1]' => 'Monero \\(XMR\\)',
                            '__SECURITY_DEPT,[l=1]' => '(?i)\\bsecurity dep(?:artmen)?t\\b',
                            '__TRAVEL_PROFILE,[l=1]' => '(?i)\\btravel+er\\sprofile\\b',
                            'BAD_CREDIT,[l=1]' => '(?i)\\b((?:bad|poor|eliminate|repair|(?:re)?establish|damag).{0,10} (?:credit|debt)|no credit (?:check|histor|need))',
                            '__MAKE_XTRA_DOLLAR,[l=1]' => '(?i)\\bmake an extra dollar\\b',
                            '__FRAUD_XVW,[l=1]' => '(?i)\\bhonest cooperation\\b',
                            '__PUMPDUMP_03,[l=1]' => '(?i)\\bbuy (?:[^.!]{1,30} )?(?:(?:(?:mon|tues|wednes|thurs|fri)day|tomorrow) (?:first thing|open|morning)|(?:first thing|opens|before) (?:(?:mon|tues|wednes|thurs|fri)day|tomorrow))',
                            '__I_WILL_YOU,[l=1]' => '(?i)\\bwill(?:ed)?\\s(?:[a-z\\s]{0,20}(?:fortune|money|\\$[\\d,]+[a-z]{0,9})\\s)?to\\syou\\b',
                            '__DOS_LET_GO_JOB,[l=1]' => 'I was (?:let go|fired|layed off|dismissed) from a job I h(?:el|a)d for (?:2\\d years|\\d{3} months)',
                            '__YOU_WON_02,[l=1]' => '(?i)\\bw[io]n\\s(?:(?:for|by)\\s)?your?\\b',
                            '__DOS_WRITE_ME_AT,[l=1]' => '[Ww].?r.?i.?t.?e me at',
                            '__VBOUNCE_ATTACHMENT0,[l=1]' => '(?:Attachment.{0,40}was Deleted|the infected attachment)',
                            '__FRAUD_QFY,[l=1]' => '(?i)\\bover-? *(?:invoiced?|cost(?:s|ing)?)\\b',
                            '__FRAUD,[l=1]' => '(?i)\\b(?:de)?fraud',
                            '__FRAUD_WNY,[l=1]' => '(?i)\\b(?:disburse?(?:ment)?|incurr?(?:ed)?|remunerr?at(?:ed?|ion)|remm?itt?(?:ed|ance|ing)?)\\b',
                            '__hk_win_9,[l=1]' => '(?i)\\blucky (?:nl )number',
                            '__FRAUD_AXF,[l=0]' => '(?i)magnanimity',
                            '__FRAUD_KJV,[l=0]' => '(?i)(?:claim|concerning) (?:the|this) money',
                            '__LOTTO_AGENT_02,[l=1]' => '(?i)\\blot+ery[^\\.]{1,40} ticket agent',
                            '__DRUGS_ERECTILE_L,[l=1]' => '(?i)\\bLevitra\\b',
                            '__INHERIT_PMT,[l=1]' => '(?i)\\binheritance\\spayment\\s',
                            '__DRUGS_ANXIETY2,[l=1]' => '(?i)\\bAlprazolam\\b',
                            'STOCK_ALERT,[l=1]' => '(?i)\\bstock alert',
                            '__VBOUNCE_EXIM,[l=1]' => 'a potentially executable attachment ',
                            'LONG_TERM_PRICE,[l=1]' => '(?i)long\\W+term\\W+(target|projected)(\\W+price)?',
                            'FIN_FREE,[l=1]' => '(?i)\\bfinancial(?:ly)? (?:free|independen)',
                            '__DOS_EMAIL_DIRECTLY,[l=1]' => '(?:Email m[a-z]?e|address) direc(?:tl|lt)y at',
                            'DX_TEXT_03,[l=1]' => '\\b[A-Z]{3} Media (?:Group|Relations)\\b',
                            '__FOR_SALE_PRC_1K,[l=1]' => '(?i)\\bprice:? \\$\\d,?\\d\\d\\d[.\\s]',
                            '__MAIL_ACCT_ACCESS1,[l=1]' => '(?i)\\b(?:your (?:web ?|e-?)?mail (?:account|log-?in) (?:has )?been accessed|r(?:=F3|[\\xf3])zne komputery zalogowaniu sie)\\b',
                            '__INVEST_COUNTRY,[l=1]' => '(?i)\\binvest\\sin\\syour?\\scountry\\b',
                            'REMOVE_BEFORE_LINK,[l=1]' => '(?i)(?:no thanks|not interested|unsubscribe here).{0,5}http://',
                            '__OUR_BEHALF,[l=1]' => '(?i)\\b(?:on\\s(?:my|our)\\sbehalf|of\\sbehalf\\sof)\\b',
                            '__VBOUNCE_MAILSWEEP,[l=1]' => 'MAILsweeper has found that a \\S+ \\S+ \\S+ \\S+ one or more virus',
                            '__FRAUD_BEP,[l=1]' => '(?i)\\b(?:bank of nigeria|central bank of|trust bank|apex bank|amalgamated bank)\\b',
                            '__DOS_I_DRIVE_A,[l=1]' => 'I drive a',
                            'MARKETING_PARTNERS,[l=1]' => '(?i)\\b(?:marketing|network) partner|\\bpartner (?:web)?site',
                            '__WIRE_XFR,[l=1]' => '(?i)\\b(?:wire|telegraph(?:ic)?|bank)\\s?transfer',
                            '__DRUGS_ERECTILE5,[l=1]' => '(?i)\\b_{0,3}s[_\\W]?[i1!|l\\xEC-\\xEF][_\\W]?l[_\\W]?d[_\\W]?[e3\\xE8-\\xEB][_\\W]?n[_\\W]?[a4\\xE0-\\xE6@][_\\W]?f[_\\W]?[i1!|l\\xEC-\\xEF][_\\W]?l c[_\\W]?[i1!|l\\xEC-\\xEF][_\\W]?t[_\\W]?r[_\\W]?[a4\\xE0-\\xE6@][_\\W]?t[_\\W]?[e3\\xE8-\\xEB]_{0,3}(?:\\b|\\s)',
                            'TVD_ACT_193,[l=1]' => '(?i)\\bact of (?:193|nineteen thirty)',
                            'LOW_PRICE,[l=1]' => '(?i)\\blow.{0,4} (?-i:P)rice',
                            'DIET_1,[l=1]' => '(?i)\\b(?:(?:without|no) (?:exercis(?:e(?! price)|ing)|dieting)|weight.?loss|(?:extra|lose|lost|losing).{0,10}(?:pounds|weight|inches|lbs)|burn.{1,10}fat)\\b',
                            '__VBOUNCE_VALERT,[l=1]' => 'The mail message \\S+ \\S+ you sent to \\S+ contains the virus',
                            'UNCLAIMED_MONEY,[l=1]' => '(?i)\\bunclaimed\\s(?:assets?|accounts?|mon(?:ey|ies)|balance|funds?|prizes?|rewards?|payments?|deposits?)\\b',
                            '__TVD_PH_BODY_08,[l=1]' => '(?i)\\bmultiple password failures',
                            'PREST_NON_ACCREDITED,[l=1]' => '(?i)prestigi?ous\\b.{0,20}\\bnon-accredited\\b.{0,20}\\buniversities',
                            '__FRAUD_MLY,[l=1]' => '(?i)\\b(?:reply|respond)\\b[^.]{0,50}\\b(?:to|through)\\b[^.]{0,50}\\@\\b',
                            '__hk_win_3,[l=1]' => '(?i)\\bhappily aa?nnounce',
                            '__YOU_INHERIT,[l=1]' => '(?i)\\byour\\s[a-z\\s]{0,30}inherit+ance\\b',
                            '__NEVER_HEAR_IT,[l=0]' => '(?i)eliminare tutti i tuoi segreti|Ti garantisco che non ti disturbe',
                            '__DIPLOMATIC,[l=1]' => '(?i)\\bdiplomatic\\b',
                            '__PUMPDUMP_09,[l=1]' => '(?i)\\b(?:buy|get|snap up|grab) as many shares (?:of it )?as (?:you|I) can\\b',
                            '__DOS_STRONG_CF,[l=1]' => '(?i)\\bstrong cash flow',
                            '__NEVER_HEAR_EN,[l=0]' => '(?i)(never hear me again|destroy all your secrets|not bother you again|leave you alone)',
                            '__TRAVEL_BUSINESS,[l=1]' => '(?i)\\bbusiness\\stravel\\b',
                            '__UNSUB_GOOG_FORM,[l=1]' => '(?i)Unsub?sc?ribe\\s<?https?://docs\\.google\\.com/forms/',
                            '__DRUGS_PAIN12,[l=1]' => '(?i)\\besgic plus\\b',
                            'BODY_ENHANCEMENT,[l=1]' => '(?i)\\b(?:enlarge|increase|grow|lengthen|larger\\b|bigger\\b|longer\\b|thicker\\b|\\binches\\b).{0,50}\\b(?:penis|male organ|pee[ -]?pee|dick|sc?hlong|wh?anger|breast(?!\\s+cancer))',
                            '__FEES,[l=1]' => '(?i)\\b(?:security|safe\\w*|courier|registration|pay|paid|up-?front|processing|delivery|transfer|keeping)[\\s\\w]{0,15}\\s(?:fee|charge)s?\\b',
                            '__PASSIVE_INCOME,[l=1]' => '(?i)\\bpassive income\\b',
                            'REPLICA_WATCH,[l=1]' => '(?i)\\breplica.{1,20}rolex',
                            '__VBOUNCE_QUOTED_EXE,[l=1]' => '> TVqQAAMAAAAEAAAA',
                            '__MILLIONS,[l=1]' => '(?i)\\bmillions\\sof\\s(?:dollar|euro|pound)',
                            '__PDS_SEO2,[l=1]' => '(?i)losing your (?:[a-z]+ )?(?:rank(?:ing)?|results)|rank well on [a-z]+\\b',
                            '__DOS_I_AM_25,[l=1]' => 'I a.?m 25',
                            '__SURVEY,[l=1]' => '(?i)\\bsurvey\\b',
                            '__CLEAN_MAILBOX,[l=1]' => '(?i)\\b(?:(?:e-?mail|mail\\s?box|violation:|(?-i:CLICK)) (?:quota size|clean(?:-?up))|clean ?up click ?here|(?:please|automatically) reduce (?:your|the) e?-?mail ?box size|reduce (?:your |the )?(?:e?-?mail(?: ?box)? )?size automatically)\\b',
                            '__FRAUD_PTS,[l=1]' => '(?i)\\b(?:ass?ass?inat(?:ed|ion)|murder(?:e?d)?|kill(?:ed|ing)\\b[^.]{0,99}\\b(?:war veterans|rebels?))\\b',
                            '__hk_win_a,[l=1]' => '(?i)\\bwinning (?:e-?mail|numbers|information)',
                            '__YOU_WON_01,[l=1]' => '(?i)\\byou(?:r|\'re|\'ve|\'ll|\\shave|\\sdid)?\\s(?:e-?mail\\s)?(?:\\w+\\s){0,2}(?:a\\s)?w[io]n+(?:er|ing)?(?!\\xe2\\x80\\x99t)(?![`\'\\x92]t)\\b',
                            '__HK_LOTTO_BALLOT,[l=1]' => '(?i)\\b(?:promotional|on.?line|computer|internet|e-?mail|fran.aise) (?:ballot|draw|sweepstake)',
                            'FORWARD_LOOKING,[l=1]' => '(?i)\\bcontains forward-looking statements\\b',
                            '__YOUR_PROFIT,[l=1]' => '(?i)\\byour?\\sprofit',
                            '__HK_SCAM_S15,[l=0]' => '(?i)(?:discovered a dormant account|can you be my partner)',
                            '__URG_BIZ,[l=1]' => '(?i)urgent.{0,16}(?:assistance|business|buy|confidential|notice|proposal|reply|request|response)',
                            'NO_PRESCRIPTION,[l=1]' => '(?i)N[o0].{1,10}P(?:er|re)scr[i1]pt[i1][o0]n.{1,10}(?:n[e3][e3]d[e3]d|requ[1i]re|n[e3]c[e3]ssary)',
                            '__FOR_SALE_NET,[l=1]' => '(?i)00\\.? NET',
                            '__DIED_IN,[l=1]' => '(?i)\\bdied\\sin\\b',
                            'FREE_PORN,[l=1]' => '(?i)\\bfree (?:porn|xxx|adult)',
                            '__COPY_PASTE_DE,[l=0]' => '(?i)Kopieren Sie es und f(?:\\xfc|\\xc3\\xbc)gen Sie es ein|Kopieren \\& Einf(?:\\xfc|\\xc3\\xbc)gen',
                            '__DRUGS_PAIN2,[l=1]' => '(?i)\\b_{0,3}c[o0\\xF2-\\xF6]deine_{0,3}\\b',
                            'DRUG_ED_ONLINE,[l=1]' => '(?i)\\bviagra .{0,25}(?:express|online|overnight)',
                            'BANKING_LAWS,[l=0]' => '(?i)banking laws',
                            '__VBOUNCE_MAILMARSHAL,[l=1]' => 'Mail.?Marshal Rule: Inbound Messages : Block Dangerous Attachments',
                            'BODY_ENHANCEMENT2,[l=1]' => '(?i)\\b(?:penis|male organ|pee[ -]?pee|dick|sc?hlong|wh?anger|breast(?!\\s+cancer)).{0,50}\\b(?:enlarge|increase|grow|lengthen|larger\\b|bigger\\b|longer\\b|thicker\\b|\\binches\\b|size)',
                            '__COPY_PASTE_NL,[l=0]' => '(?i)kopieer en plak het',
                            '__hk_win_b,[l=1]' => '(?i)\\byour e-?mail (?:address )?(?:has )?w[io]n',
                            '__GAPPY_SALES_LEADS,[l=1]' => '(?i)\\b(?:business|e?-?mail|your|marketing|advertising)\\s(?!sales|leads|campaign)(?:s\\s?a\\s?l\\s?e\\s?s|l\\s?e\\s?a\\s?d\\s?s|c\\s?a\\s?m\\s?p\\s?a\\s?i\\s?g\\s?n)\\b',
                            '__BOUNCE_OOO_CB2,[l=1]' => '(?i)\\bon (?:vacation|holiday)\\b',
                            '__CAN_HELP,[l=1]' => '(?i)\\bcan help\\b',
                            'VIA_GAP_GRA,[l=1]' => '(?i)\\bvia.gra\\b',
                            '__INTL_BANK,[l=1]' => '(?i)\\b(?:international\\s(?:\\w+\\s)?bank|banque\\sinternationale)\\b',
                            '__RUDE_HTML_1,[l=0]' => '(?i)Get a capable html e-mailer',
                            'ACT_NOW_CAPS,[l=1]' => '\\bA(?i:ct) N(?i:ow)\\b',
                            '__hk_win_j,[l=1]' => '(?i)\\b(?:winning|ready for|sum) pay ?out',
                            '__TRUNK_BOX,[l=1]' => '(?i)\\b(?:(?:trunk|metallic|proof|security|consignment)\\sbox(?:es)?|sealed\\ssafe|une mallette m(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])tallique)\\b',
                            '__HK_SCAM_N16,[l=1]' => '(?i)\\b(?:arrangement secret|secret arrangement)\\b',
                            '__DOS_BODY_STOCK,[l=1]' => '(?i)\\bstock\\b',
                            '__STOCK_TIP,[l=1]' => '(?i)\\bsto[ck]{2}\\s?tip\\b',
                            '__FRAUD_JBU,[l=1]' => '(?i)\\bforeign account\\b',
                            '__DESTROY_ME,[l=1]' => '(?i)\\b(?:destroy|hunt|quemar)\\sm[eyi]\\b',
                            '__LOTSA_MONEY_05,[l=1]' => '(?i)(?:(?:sum|value|amount)\\sof\\s)<NUM_NOT_DATE_IP>[\\d.,\\sO]{7,20}[\\dO\\.][\\)\\]\\(\\s]{0,3}(?:pounds?|dollars?|euros?|bucks)\\b',
                            '__FRAUD_YJA,[l=0]' => '(?i)over-invoice',
                            '__MAIL_ACCT_ACCESS2,[l=1]' => '(?i)\\blo+se ac+es+ to your (?:web|e-?)?mail ?(?:account|log-?in|box|address)\\b',
                            '__HUSH_HUSH,[l=1]' => '(?i)\\b(?:confiden[tc]i[ae]l(?:\\b|ity\\b|it(?:=E9|[\\xe9]|[\\xc3][\\xa9]))|private\\b|secr[e\\xe8](?:te?|cy)\\b|sensitive\\b|concealed\\b|obscured?\\b|discre(?:et|tion)\\b|very\\sdiscrete|top\\ssecret|vertraulich(?:en)?\\b|geheim\\b|priv(?:e|=E9|[\\xe9]|[\\xc3][\\xa9]))',
                            'PRICES_ARE_AFFORDABLE,[l=1]' => '(?i)\\baffordable .{0,10}prices\\b',
                            '__VBOUNCE_SECURIQ,[l=1]' => '\\bGROUP securiQ.Wall\\b',
                            '__hk_win_7,[l=1]' => '(?i)\\bcongratulations? to your',
                            '__WITHOUT_EFFORT,[l=1]' => '(?i)\\bwith(?:out(?: a(?:ny)?| the)?| no)(?: great| special| extra)? effort\\b',
                            '__YOU_WON_05,[l=1]' => '(?i)\\bI won(?!\\xe2\\x80\\x99t)(?![`\'\\x92]t)\\b',
                            '__FRAUD_FVU,[l=0]' => '(?i)award notification',
                            '__VBOUNCE_CLICKBANK,[l=1]' => '(?i)\\bvirus scanner deleted your message\\b',
                            'REFINANCE_NOW,[l=1]' => '(?i)time to refinance|refinanc\\w{1,3}\\b.{0,16}\\bnow\\b',
                            '__HAS_WON_01,[l=1]' => '(?i)\\bque ha ganado\\b',
                            '__INVEST_MONEY,[l=1]' => '(?i)\\binvest(?:ir)?\\s(?:this|ces|d[ae]s|sur ce|de ces)\\s(?:money|f[ou]nds?)\\b',
                            'MALE_ENHANCE,[l=0]' => '(?i)male enhancement',
                            '__BOUNCE_NEVER_SEE,[l=1]' => '(?i)\\bThis is an autoresponder. I\'ll never see your message\\b',
                            '__hk_win_8,[l=1]' => '(?i)\\bunexpected luck',
                            '__hk_win_5,[l=1]' => '(?i)\\b(?:notice the|your) winning',
                            '__hk_win_4,[l=1]' => '(?i)\\bpleas(?:ure|ed) to inform',
                            'LIVE_PORN,[l=1]' => '(?i)\\blive .{0,9}(?:fuck(?:ing)?|sex|naked|girls?|virgins?|teens?|porno?)\\b',
                            'EXCUSE_24,[l=1]' => '(?i)you(?:\'ve|\'re| have| are)? receiv(?:e|ed|ing) this (?:advertisement|offer|special|recurring|paid).{0,16}\\b(?:by either|because)',
                            '__FRAUD_CKF,[l=0]' => '(?i)computer ballot system',
                            '__YOUR_FUND,[l=1]' => '(?i)\\b(?:your|ihr)\\s(?:unpaid\\s|win+ing\\s|ap+roved\\s|foreign\\s|overdue\\s|outstanding\\s|contract\\s|inheritance\\s|nicht\\sausbezahlten\\s){0,3}(?:fund|f\\su\\sn\\sd|payment|geld)\\b',
                            '__CHARITY,[l=1]' => '(?i)\\b(?:charit(?:y|[ai]ble)|orphans?|homeless|orphelins|sans\\sabri)\\b',
                            'NO_MEDICAL,[l=1]' => '(?i)\\bno medical exam',
                            'ONE_TIME,[l=1]' => '(?i)\\bone\\W+time (?:charge|investment|offer|promotion)',
                            '__BONUS_LAST_DAY,[l=1]' => '(?i)\\b(?:last|final) day of the (?:\\$\\d+ |\\d+ dollars? )?bonus offer(?:ing)?\\b',
                            '__PASSWORD_UPGRADE,[l=1]' => '(?i)\\bpassword upgrade\\b',
                            'TVD_PH_REC,[l=1]' => '(?i)\\byour .{0,40}account .{0,40}record',
                            '__DOS_LINK,[l=1]' => '\\blink\\b',
                            'TVD_PH_7,[l=1]' => '(?i)\\baccount .{0,20}suspen',
                            '__FOUND_YOU,[l=1]' => '(?i)\\b(?:I|we)\\sfound\\syour?\\b',
                            '__FRAUD_YQV,[l=0]' => '(?i)nigerian? (?:national|government)',
                            '__DOS_CORRESPOND_EMAIL,[l=1]' => 'correspond with me using my email'
                          }
         };
